@@ -24,9 +24,9 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
 {
     this->setWindowTitle(tr("Account Configuration") + " - Dianara");
     this->setWindowIcon(QIcon::fromTheme("dialog-password"));
-    this->setWindowFlags(Qt::Window);
+    this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::ApplicationModal);
-    this->setMinimumSize(640, 320);
+    this->setMinimumSize(640, 360);
 
     this->pController = pumpController;
 
@@ -87,7 +87,8 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
 
     // To notify invalid ID or empty verifier code
     // Cleared when typing in any of the two fields
-    errorsLabel = new QLabel("");
+    errorsLabel = new QLabel();
+    errorsLabel->setOpenExternalLinks(true);
     connect(userIDLineEdit, SIGNAL(textChanged(QString)),
             errorsLabel, SLOT(clear()));
     connect(verifierLineEdit, SIGNAL(textChanged(QString)),
@@ -99,8 +100,6 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     authorizationStatusFont.setBold(true);
 
     authorizationStatusLabel = new QLabel();
-    authorizationStatusLabel->setTextInteractionFlags(Qt::TextSelectableByKeyboard
-                                                      | Qt::TextSelectableByMouse);
     authorizationStatusLabel->setFont(authorizationStatusFont);
 
 
@@ -129,7 +128,7 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     idLayout->addWidget(getVerifierButton);
     mainLayout->addLayout(idLayout, 3);
     mainLayout->addStretch(3);
-    mainLayout->addSpacing(8);
+    mainLayout->addSpacing(12);
 
     mainLayout->addWidget(helpMessage2Label, 3);
     mainLayout->addStretch(2);
@@ -142,10 +141,11 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     verifierLayout->addWidget(authorizeApplicationButton);
     mainLayout->addLayout(verifierLayout, 3);
 
-    mainLayout->addWidget(errorsLabel, 1, Qt::AlignCenter);
+    mainLayout->addWidget(errorsLabel,              1, Qt::AlignCenter);
+    mainLayout->addSpacing(4);
     mainLayout->addWidget(authorizationStatusLabel, 1, Qt::AlignCenter);
     mainLayout->addStretch(2);
-    mainLayout->addSpacing(8);
+    mainLayout->addSpacing(16);
 
     this->buttonsLayout = new QHBoxLayout();
     buttonsLayout->setAlignment(Qt::AlignRight);
@@ -179,8 +179,6 @@ AccountDialog::~AccountDialog()
 
 
 
-
-
 //////////////////////////////////////////////////////////////////////
 ///////////////////////////////// SLOTS //////////////////////////////
 //////////////////////////////////////////////////////////////////////
@@ -206,7 +204,10 @@ void AccountDialog::askForToken()
 
 
         // Show message about the web browser that will be started
-        this->errorsLabel->setText("[ " + tr("A web browser will start now, where you can get the verifier code") + " ]");
+        this->errorsLabel->setText("[ "
+                                   + tr("A web browser will start now, "
+                                        "where you can get the verifier code")
+                                   + " ]");
 
         this->pController->setNewUserId(userIDLineEdit->text());
         this->pController->getToken();
@@ -222,11 +223,12 @@ void AccountDialog::askForToken()
 
 void AccountDialog::setVerifierCode()
 {
-    qDebug() << "AccountDialog::setVerifierCode()" << this->verifierLineEdit->text();
+    qDebug() << "AccountDialog::setVerifierCode()"
+             << this->verifierLineEdit->text();
 
-    if (!this->verifierLineEdit->text().isEmpty())
+    if (!this->verifierLineEdit->text().trimmed().isEmpty())
     {
-        this->pController->authorizeApplication(this->verifierLineEdit->text());
+        this->pController->authorizeApplication(this->verifierLineEdit->text().trimmed());
     }
     else
     {
@@ -242,7 +244,8 @@ void AccountDialog::showAuthorizationStatus(bool authorized)
     if (authorized)
     {
         this->authorizationStatusLabel->setText(QString::fromUtf8("\342\234\224 ") // Check mark
-                                                + tr("Dianara is authorized to access your data"));
+                                                + tr("Dianara is authorized to "
+                                                     "access your data"));
     }
     else
     {
@@ -260,10 +263,12 @@ void AccountDialog::showAuthorizationURL(QUrl url)
 {
     QString message = tr("If the browser doesn't open automatically, "
                          "copy this address manually")
-                      + ":\n"
+                      + ":<br><a href=\""
                       + url.toString()
-                      + "\n";
-    this->authorizationStatusLabel->setText(message);
+                      + "\">"
+                      + url.toString()
+                      + "</a>";
+    this->errorsLabel->setText(message);
 }
 
 
@@ -279,13 +284,12 @@ void AccountDialog::saveDetails()
     QString newUserID = this->userIDLineEdit->text().trimmed();
     if (newUserID.isEmpty() || !newUserID.contains("@"))
     {
-        return;  // If no user ID, or with no "@", ignore
+        return;  // If no user ID, or with no "@", ignore // FIXME
     }
 
     QSettings settings;
     settings.setValue("userID", newUserID);
 
-
     emit userIDChanged(userIDLineEdit->text());
 
 
