@@ -38,9 +38,17 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
 
     this->setWindowTitle(titlePart + " - Dianara");
     this->setWindowIcon(QIcon::fromTheme("system-users"));
-    this->setWindowFlags(Qt::Window);
+    this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::WindowModal);
-    this->setMinimumSize(300, 300);
+    this->setMinimumSize(440, 340);
+
+    QSettings settings;
+    QSize savedWindowsize = settings.value("AudienceSelector/"
+                                           "audienceWindowSize").toSize();
+    if (savedWindowsize.isValid())
+    {
+        this->resize(savedWindowsize);
+    }
 
 
 
@@ -73,6 +81,7 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     selectedListWidget->setDragDropMode(QListView::DragDrop);
     selectedListWidget->setDefaultDropAction(Qt::MoveAction);
     selectedListWidget->setSelectionMode(QListView::ExtendedSelection);
+    selectedListWidget->setIconSize(QSize(48, 48));
 
     this->clearSelectedListButton = new QPushButton(QIcon::fromTheme("edit-clear-list"),
                                                     tr("Clear &List"));
@@ -240,6 +249,15 @@ void AudienceSelector::keyPressEvent(QKeyEvent *event)
 void AudienceSelector::closeEvent(QCloseEvent *event)
 {
     this->resetLists();
+    this->hide();
+
+    event->accept();
+}
+
+void AudienceSelector::hideEvent(QHideEvent *event)
+{
+    QSettings settings;
+    settings.setValue("AudienceSelector/audienceWindowSize", this->size());
 
     event->accept();
 }
