@@ -32,6 +32,8 @@
 #include <QPushButton>
 #include <QKeyEvent>
 #include <QCloseEvent>
+#include <QHideEvent>
+#include <QSettings>
 
 #include <QDebug>
 
@@ -55,10 +57,6 @@ public:
     void restoreSelected();
 
 
-protected:
-    virtual void keyPressEvent(QKeyEvent *event);
-    virtual void closeEvent(QCloseEvent *event);
-
 signals:
     void audienceSelected(QString selectorType,
                           QStringList contactsList);
@@ -71,6 +69,11 @@ public slots:
     void setAudience();
 
 
+protected:
+    virtual void keyPressEvent(QKeyEvent *event);
+    virtual void closeEvent(QCloseEvent *event);
+    virtual void hideEvent(QHideEvent *event);
+
 
 private:
     QString selectorType;
