@@ -58,14 +58,9 @@ AvatarButton::AvatarButton(ASPerson *person,
 
 
     this->authorId = person->getId();
-    this->authorName = person->getName();
-    // In case there's no name to show, for some reason, use ID
-    if (authorName.isEmpty()) // This happens sometimes with shared objects
-    {
-        authorName = authorId;
-    }
-    authorUrl = person->getUrl();
-    authorAvatarUrl = person->getAvatar();
+    this->authorName = person->getNameWithFallback();
+    this->authorUrl = person->getUrl();
+    this->authorAvatarUrl = person->getAvatar();
 
 
     // Get "following" status before creating avatar menu
