@@ -30,6 +30,7 @@
 #include <QMessageBox>
 #include <QEvent>
 #include <QResizeEvent>
+
 #include <QDebug>
 
 #include "pumpcontroller.h"
@@ -38,6 +39,7 @@
 #include "timestamp.h"
 #include "asobject.h"
 #include "avatarbutton.h"
+#include "hclabel.h"
 
 
 class Comment : public QFrame
@@ -88,9 +90,9 @@ private:
 
     AvatarButton *avatarButton;
     QLabel *fullNameLabel;
-    QLabel *timestampLabel;
+    HClabel *timestampLabel;
     QLabel *contentLabel;
-    QLabel *likesCountLabel;
+    HClabel *likesCountLabel;
 
     QLabel *likeLabel;
     QLabel *quoteLabel;
