@@ -105,16 +105,18 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
                                                            QIcon(":/images/button-post.png")),
                                           tr("Comment",
                                              "Infinitive verb"));
-    commentButton->setToolTip(tr("You can press Control+Enter to send "
-                                 "the comment with the keyboard") + "<b></b>");
+    commentButton->setToolTip("<b></b>"
+                              + tr("You can press Control+Enter to send "
+                                   "the comment with the keyboard"));
     connect(commentButton, SIGNAL(clicked()),
             this, SLOT(sendComment()));
 
     this->cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
                                                           QIcon(":/images/button-cancel.png")),
                                          tr("&Cancel"));
-    cancelButton->setToolTip(tr("Press ESC to cancel the comment "
-                                "if there is no text") + "<b></b>");
+    cancelButton->setToolTip("<b></b>"
+                             + tr("Press ESC to cancel the comment "
+                                  "if there is no text"));
     connect(cancelButton, SIGNAL(clicked()),
             commentComposer, SLOT(cancelPost()));
 
@@ -217,6 +219,18 @@ void CommenterBlock::adjustCommentsWidth()
 }
 
 
+bool CommenterBlock::isFullMode()
+{
+    return this->fullMode;
+}
+
+
+Composer *CommenterBlock::getComposer()
+{
+    return this->commentComposer;
+}
+
+
 
 /*******************************************************************/
 /****************************** SLOTS ******************************/
