@@ -53,6 +53,11 @@ public:
 
     void adjustCommentsWidth();
 
+    bool isFullMode();
+
+    Composer *getComposer();
+
+
 signals:
     void commentSent(QString commentText);
     void commentUpdated(QString commentId, QString commentText);
