@@ -33,11 +33,18 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     this->setWindowTitle(tr("Program Configuration") + " - Dianara");
     this->setWindowIcon(QIcon::fromTheme("configure",
                                          QIcon(":/images/button-configure.png")));
-    this->setWindowFlags(Qt::Window);
+    this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::ApplicationModal);
     this->setMinimumSize(560, 420);
 
     QSettings settings;
+    QSize savedWindowsize = settings.value("ConfigDialog/configWindowSize").toSize();
+    if (savedWindowsize.isValid())
+    {
+        this->resize(savedWindowsize);
+    }
+
+
     settings.beginGroup("Configuration");
 
     // Standalone Proxy config window
@@ -105,6 +112,12 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     generalOptionsLayout->addRow(tr("Public posts as &default"),
                                  publicPostsCheckbox);
 
+
+    QFrame *lineFrame1 = new QFrame();
+    lineFrame1->setFrameStyle(QFrame::HLine);
+    generalOptionsLayout->addRow(lineFrame1);
+
+
     proxyConfigButton = new QPushButton(QIcon::fromTheme("preferences-system-network"),
                                         tr("Pro&xy Settings"));
     connect(proxyConfigButton, SIGNAL(clicked()),
@@ -112,13 +125,36 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     generalOptionsLayout->addRow(tr("Network configuration"),
                                  proxyConfigButton);
 
-    filterEditorButton = new QPushButton(QIcon::fromTheme("view-filter"),
+    filterEditorButton = new QPushButton(QIcon::fromTheme("view-filter",
+                                                          QIcon(":/images/button-filter.png")),
                                          tr("Set Up F&ilters"));
     connect(filterEditorButton, SIGNAL(clicked()),
             this, SIGNAL(filterEditorRequested()));
     generalOptionsLayout->addRow(tr("Filtering rules"),
                                  filterEditorButton);
 
+    QFrame *lineFrame2 = new QFrame();
+    lineFrame2->setFrameStyle(QFrame::HLine);
+    generalOptionsLayout->addRow(lineFrame2);
+
+
+    minorFeedSnippetsCombobox = new QComboBox();
+    minorFeedSnippetsCombobox->addItem(tr("Highlighted activities, except mine"));
+    minorFeedSnippetsCombobox->addItem(tr("Any highlighted activity"));
+    minorFeedSnippetsCombobox->addItem(tr("Always"));
+    minorFeedSnippetsCombobox->addItem(tr("Never"));
+    minorFeedSnippetsCombobox->setCurrentIndex(globalObj->getMinorFeedSnippetsType());
+    generalOptionsLayout->addRow(tr("Show snippets in minor feed"),
+                                 minorFeedSnippetsCombobox);
+
+    snippetLimitSpinbox = new QSpinBox();
+    snippetLimitSpinbox->setRange(10, 10000);
+    snippetLimitSpinbox->setSuffix(" " + tr("characters",
+                                            "This is a suffix, after a number"));
+    snippetLimitSpinbox->setValue(globalObj->getSnippetsCharLimit());
+    generalOptionsLayout->addRow(tr("Snippet limit"),
+                                 snippetLimitSpinbox);
+
     generalOptionsWidget = new QWidget();
     generalOptionsWidget->setLayout(generalOptionsLayout);
 
@@ -150,24 +186,25 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     // Tab 3, colors
     this->colorOptionsLayout = new QVBoxLayout();
 
+    QStringList colorList = globalObj->getColorsList();
     colorPicker1 = new ColorPicker(tr("You are among the recipients "
                                       "of the activity, such as "
                                       "a comment addressed to you.")
                                    + "\n"
                                    + tr("Used also when highlighting posts "
                                         "addressed to you in the timelines."),
-                                   settings.value("color1", "DISABLED#401020").toString());
+                                   colorList.at(0));
     colorOptionsLayout->addWidget(colorPicker1);
 
     colorPicker2 = new ColorPicker(tr("The activity is in reply to something "
                                       "done by you, such as a comment posted "
                                       "in reply to one of your notes."),
-                                   settings.value("color2", "DISABLED#154060").toString());
+                                   colorList.at(1));
     colorOptionsLayout->addWidget(colorPicker2);
 
     colorPicker3 = new ColorPicker(tr("You are the object of the activity, "
                                       "such as someone adding you to a list."),
-                                   settings.value("color3", "DISABLED#403510").toString());
+                                   colorList.at(2));
     colorOptionsLayout->addWidget(colorPicker3);
 
     colorPicker4 = new ColorPicker(tr("The activity is related to one of "
@@ -176,15 +213,15 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                                    + "\n"
                                    + tr("Used also when highlighting your "
                                         "own posts in the timelines."),
-                                   settings.value("color4", "DISABLED#103510").toString());
+                                   colorList.at(3));
     colorOptionsLayout->addWidget(colorPicker4);
 
     colorPicker5 = new ColorPicker(tr("Item highlighted due to filtering rules."),
-                                   settings.value("color5").toString());
+                                   colorList.at(4));
     colorOptionsLayout->addWidget(colorPicker5);
 
     colorPicker6 = new ColorPicker(tr("Item is new."),
-                                   settings.value("color6").toString());
+                                   colorList.at(5));
     colorOptionsLayout->addWidget(colorPicker6);
 
 
@@ -232,11 +269,10 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
     this->syncNotifierOptions();
 
-    QFrame *lineFrame = new QFrame();
-    lineFrame->setFrameStyle(QFrame::HLine);
-    lineFrame->setMinimumHeight(16);
-    notificationOptionsLayout->addRow(lineFrame);
-
+    QFrame *lineFrame3 = new QFrame();
+    lineFrame3->setFrameStyle(QFrame::HLine);
+    lineFrame3->setMinimumHeight(16);
+    notificationOptionsLayout->addRow(lineFrame3);
 
     systrayIconTypeCombobox = new QComboBox();
     systrayIconTypeCombobox->addItem(tr("Default"));
@@ -273,22 +309,46 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
 
 
 
-    //// Tab widget
-    tabWidget = new QTabWidget();
-    tabWidget->setSizePolicy(QSizePolicy::MinimumExpanding,
-                             QSizePolicy::MinimumExpanding);
-    tabWidget->addTab(generalOptionsWidget,
-                      QIcon::fromTheme("preferences-other"),
-                      tr("&General Options"));
-    tabWidget->addTab(fontOptionsWidget,
-                      QIcon::fromTheme("preferences-desktop-font"),
-                      tr("&Fonts"));
-    tabWidget->addTab(colorOptionsWidget,
-                      QIcon::fromTheme("preferences-desktop-color"),
-                      tr("Co&lors"));
-    tabWidget->addTab(notificationOptionsWidget,
-                      QIcon::fromTheme("preferences-desktop-notification"),
-                      tr("&Notifications and System Tray"));
+    ///////////////////////////////////// List of categories and stacked widget
+    categoriesListWidget = new QListWidget();
+    categoriesListWidget->setSizePolicy(QSizePolicy::Preferred,
+                                        QSizePolicy::MinimumExpanding);
+    categoriesListWidget->setMinimumWidth(100); // kinda TMP/FIXME
+#if 0 // enable for large-icon-mode with text below
+    categoriesListWidget->setViewMode(QListView::IconMode);
+    categoriesListWidget->setFlow(QListView::TopToBottom);
+    categoriesListWidget->setIconSize(QSize(48, 48));
+    categoriesListWidget->setWrapping(false);
+    categoriesListWidget->setMovement(QListView::Static);
+#endif
+    categoriesListWidget->setIconSize(QSize(32, 32));
+    categoriesListWidget->setUniformItemSizes(true);
+    categoriesListWidget->setWordWrap(true);
+    categoriesListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+
+    categoriesListWidget->addItem(tr("General Options"));
+    categoriesListWidget->item(0)->setIcon(QIcon::fromTheme("preferences-other"));
+    categoriesListWidget->addItem(tr("Fonts"));
+    categoriesListWidget->item(1)->setIcon(QIcon::fromTheme("preferences-desktop-font"));
+    categoriesListWidget->addItem(tr("Colors"));
+    categoriesListWidget->item(2)->setIcon(QIcon::fromTheme("preferences-desktop-color"));
+    categoriesListWidget->addItem(tr("Notifications and System Tray"));
+    categoriesListWidget->item(3)->setIcon(QIcon::fromTheme("preferences-desktop-notification"));
+
+    categoriesStackedWidget = new QStackedWidget();
+    categoriesStackedWidget->setSizePolicy(QSizePolicy::Preferred,
+                                           QSizePolicy::MinimumExpanding);
+    categoriesStackedWidget->addWidget(generalOptionsWidget);
+    categoriesStackedWidget->addWidget(fontOptionsWidget);
+    categoriesStackedWidget->addWidget(colorOptionsWidget);
+    categoriesStackedWidget->addWidget(notificationOptionsWidget);
+
+    connect(categoriesListWidget, SIGNAL(currentRowChanged(int)),
+            categoriesStackedWidget, SLOT(setCurrentIndex(int)));
+
+    topLayout = new QHBoxLayout();
+    topLayout->addWidget(categoriesListWidget);
+    topLayout->addWidget(categoriesStackedWidget);
 
 
 
@@ -300,9 +360,6 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
                                       .arg(dataDirectory).arg(dataDirectory));
     dataDirectoryLabel->setWordWrap(true);
     dataDirectoryLabel->setOpenExternalLinks(true);
-    QFont dataDirectoryFont;
-    dataDirectoryFont.setPointSize(dataDirectoryFont.pointSize() - 1);
-    dataDirectoryLabel->setFont(dataDirectoryFont);
 
 
     // Save / Cancel buttons
@@ -322,6 +379,8 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     buttonsLayout->addWidget(saveConfigButton);
     buttonsLayout->addWidget(cancelButton);
 
+
+    // ESC to close
     closeAction = new QAction(this);
     closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
     connect(closeAction, SIGNAL(triggered()),
@@ -329,10 +388,10 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     this->addAction(closeAction);
 
 
-    // Set up main layout
 
+    //// Set up main layout
     mainLayout = new QVBoxLayout();
-    mainLayout->addWidget(tabWidget, 2);
+    mainLayout->addLayout(topLayout, 10);
     mainLayout->addSpacing(16);
     mainLayout->addStretch(1);
     mainLayout->addWidget(dataDirectoryLabel);
@@ -341,6 +400,8 @@ ConfigDialog::ConfigDialog(GlobalObject *globalObject,
     mainLayout->addLayout(buttonsLayout);
     this->setLayout(mainLayout);
 
+    // Activate the first category (so the row already looks selected)
+    this->categoriesListWidget->setCurrentRow(0);
 
     qDebug() << "Config dialog created";
 }
@@ -384,6 +445,16 @@ void ConfigDialog::saveConfiguration()
 
     settings.setValue("publicPosts", this->publicPostsCheckbox->isChecked());
 
+    settings.setValue("minorFeedSnippets",
+                      this->minorFeedSnippetsCombobox->currentIndex());
+    settings.setValue("snippetsCharLimit",
+                      this->snippetLimitSpinbox->value());
+
+    this->globalObj->syncGeneralSettings(this->minorFeedSnippetsCombobox->currentIndex(),
+                                         this->snippetLimitSpinbox->value());
+
+
+    // Fonts
     settings.setValue("font1", this->fontPicker1->getFontInfo());
     settings.setValue("font2", this->fontPicker2->getFontInfo());
     settings.setValue("font3", this->fontPicker3->getFontInfo());
@@ -393,6 +464,7 @@ void ConfigDialog::saveConfiguration()
                                       this->fontPicker3->getFontInfo(),
                                       this->fontPicker4->getFontInfo());
 
+    // Colors
     settings.setValue("color1", this->colorPicker1->getCurrentColor());
     settings.setValue("color2", this->colorPicker2->getCurrentColor());
     settings.setValue("color3", this->colorPicker3->getCurrentColor());
@@ -400,6 +472,17 @@ void ConfigDialog::saveConfiguration()
     settings.setValue("color5", this->colorPicker5->getCurrentColor());
     settings.setValue("color6", this->colorPicker6->getCurrentColor());
 
+    QStringList highlightColorsList;
+    highlightColorsList << this->colorPicker1->getCurrentColor()
+                        << this->colorPicker2->getCurrentColor()
+                        << this->colorPicker3->getCurrentColor()
+                        << this->colorPicker4->getCurrentColor()
+                        << this->colorPicker5->getCurrentColor()
+                        << this->colorPicker6->getCurrentColor();
+    this->globalObj->syncColorSettings(highlightColorsList);
+
+
+    // Notifications and tray
     settings.setValue("showNotifications", this->notificationStyleCombobox->currentIndex());
     settings.setValue("notifyNewTL", this->notifyNewTLCheckbox->isChecked());
     settings.setValue("notifyHLTL",  this->notifyHLTLCheckbox->isChecked());
@@ -450,3 +533,23 @@ void ConfigDialog::pickCustomIconFile()
         }
     }
 }
+
+
+//////////////////////////////////////////////////////////////////////////////
+/////////////////////////////// PROTECTED ////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
+
+void ConfigDialog::closeEvent(QCloseEvent *event)
+{
+    this->hide();
+    event->ignore();
+}
+
+void ConfigDialog::hideEvent(QHideEvent *event)
+{
+    QSettings settings;
+    settings.setValue("ConfigDialog/configWindowSize", this->size());
+
+    event->accept();
+}
