@@ -26,6 +26,8 @@
 #include <QFormLayout>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
+#include <QListWidget>
+#include <QStackedWidget>
 #include <QTabWidget>
 #include <QLabel>
 #include <QSpinBox>
@@ -36,6 +38,7 @@
 #include <QAction>
 #include <QFileDialog>
 #include <QMessageBox>
+#include <QCloseEvent>
 
 #include <QDebug>
 
@@ -65,6 +68,7 @@ public:
 
     void syncNotifierOptions();
 
+
 signals:
     void configurationChanged();
     void filterEditorRequested();
@@ -75,12 +79,21 @@ public slots:
     void pickCustomIconFile();
 
 
+protected:
+    virtual void closeEvent(QCloseEvent *event);
+    virtual void hideEvent(QHideEvent *event);
+
+
 private:
     QVBoxLayout *mainLayout;
+    QHBoxLayout *topLayout;
 
-    QTabWidget *tabWidget;
 
-    // Tab 1, general options
+    QListWidget *categoriesListWidget;
+    QStackedWidget *categoriesStackedWidget;
+
+
+    // Page 1, general options
     QWidget *generalOptionsWidget;
     QFormLayout *generalOptionsLayout;
 
@@ -96,8 +109,11 @@ private:
 
     QPushButton *filterEditorButton;
 
+    QComboBox *minorFeedSnippetsCombobox;
+    QSpinBox *snippetLimitSpinbox;
 
-    // Tab 2, fonts
+
+    // Page 2, fonts
     QWidget *fontOptionsWidget;
     QVBoxLayout *fontOptionsLayout;
 
@@ -107,7 +123,7 @@ private:
     FontPicker *fontPicker4;
 
 
-    // Tab 3, colors
+    // Page 3, colors
     QWidget *colorOptionsWidget;
     QVBoxLayout *colorOptionsLayout;
 
@@ -119,7 +135,7 @@ private:
     ColorPicker *colorPicker6;
 
 
-    // Tab 4, notification and systray icon options
+    // Page 4, notification and systray icon options
     QWidget *notificationOptionsWidget;
     QFormLayout *notificationOptionsLayout;
 
@@ -142,10 +158,10 @@ private:
     QPushButton *saveConfigButton;
     QPushButton *cancelButton;
 
+
     QAction *closeAction;
 
     FDNotifications *fdNotifier;
-
     GlobalObject *globalObj;
 };
 
