@@ -29,9 +29,11 @@ ContactList::ContactList(PumpController *pumpController,
     this->globalObj = globalObject;
 
 
+    QString filterNote = tr("Type a partial name or ID to find a contact...")
+                         + " (Control+F)";
     this->filterLineEdit = new QLineEdit();
-    filterLineEdit->setPlaceholderText(tr("Type a partial name or ID to find a contact...")
-                                       + " (Ctrl+F)");
+    filterLineEdit->setPlaceholderText(filterNote);
+    filterLineEdit->setToolTip("<b></b>" + filterNote); // HTMLized for wordwrapping
     connect(filterLineEdit, SIGNAL(textChanged(QString)),
             this, SLOT(filterList(QString)));
 
