@@ -26,8 +26,9 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
     this->fChecker = filterChecker;
 
     this->setWindowTitle(tr("Filter Editor") + " - Dianara");
-    this->setWindowIcon(QIcon::fromTheme("view-filter"));
-    this->setWindowFlags(Qt::Window);
+    this->setWindowIcon(QIcon::fromTheme("view-filter",
+                                         QIcon(":/images/button-filter.png")));
+    this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::ApplicationModal);
     this->setMinimumSize(520, 400);
 
@@ -59,6 +60,7 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
                                 tr("Hide"));
     actionTypeComboBox->addItem(QIcon::fromTheme("format-fill-color"),
                                 tr("Highlight"));
+    actionTypeComboBox->setCurrentIndex(1); // #2 option (highlight) as default
 
     filterTypeComboBox = new QComboBox();
     filterTypeComboBox->addItem(QIcon::fromTheme("accessories-text-editor"),
