@@ -24,7 +24,14 @@
 GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
 {
     QSettings settings;
+    settings.beginGroup("Configuration");
 
+    /////////////////////////////////////////////////////////////////// GENERAL
+    this->syncGeneralSettings(settings.value("minorFeedSnippets", 0).toInt(),
+                              settings.value("snippetsCharLimit", 200).toInt());
+
+
+    /////////////////////////////////////////////////////////////////// FONTS
     QFont defaultTitleFont;     // 1 point larger
     defaultTitleFont.setPointSize(defaultTitleFont.pointSize() + 1);
     defaultTitleFont.setBold(true);
@@ -37,7 +44,6 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
     QFont defaultMinorFeedFont; // 2 points smaller
     defaultMinorFeedFont.setPointSize(defaultMinorFeedFont.pointSize() - 2);
 
-    settings.beginGroup("Configuration");
     this->syncFontSettings(settings.value("font1",
                                           defaultTitleFont).toString(),
                            settings.value("font2",
@@ -46,6 +52,18 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                                           defaultCommentsFont).toString(),
                            settings.value("font4",
                                           defaultMinorFeedFont).toString());
+
+
+    /////////////////////////////////////////////////////////////////// COLORS
+    this->colorsList.clear();
+    colorsList << settings.value("color1", "DISABLED#401020").toString()
+               << settings.value("color2", "DISABLED#154060").toString()
+               << settings.value("color3", "DISABLED#403510").toString()
+               << settings.value("color4", "DISABLED#103510").toString()
+               << settings.value("color5").toString()
+               << settings.value("color6").toString();
+    // no need to call this->syncColorSettings() now...
+
     settings.endGroup();
 
 
@@ -58,6 +76,29 @@ GlobalObject::~GlobalObject()
 }
 
 
+
+void GlobalObject::syncGeneralSettings(int minorFeedSnippets,
+                                       int snippetsChars)
+{
+    this->minorFeedSnippetsType = minorFeedSnippets;
+    this->snippetsCharLimit = snippetsChars;
+
+    // TODO the rest
+}
+
+int GlobalObject::getMinorFeedSnippetsType()
+{
+    return this->minorFeedSnippetsType;
+}
+
+int GlobalObject::getSnippetsCharLimit()
+{
+    return this->snippetsCharLimit;
+}
+
+
+
+
 void GlobalObject::syncFontSettings(QString postTitleFont,
                                     QString postContentsFont,
                                     QString commentsFont,
@@ -93,6 +134,20 @@ QString GlobalObject::getMinorFeedFont()
 
 
 
+void GlobalObject::syncColorSettings(QStringList newColorList)
+{
+    this->colorsList = newColorList;
+
+    qDebug() << "GlobalObject::syncColorSettings() - color list sync'd";
+}
+
+QStringList GlobalObject::getColorsList()
+{
+    return this->colorsList;
+}
+
+
+
 
 void GlobalObject::createMessageForContact(QString name, QString id)
 {
