@@ -24,6 +24,7 @@
 #include <QObject>
 #include <QSettings>
 #include <QFont>
+#include <QStringList>
 
 #include <QDebug>
 
@@ -37,6 +38,11 @@ public:
     ~GlobalObject();
 
 
+    void syncGeneralSettings(int minorFeedSnippets, int snippetsChars);
+    int getMinorFeedSnippetsType();
+    int getSnippetsCharLimit();
+
+
     void syncFontSettings(QString postTitleFont,
                           QString postContentsFont,
                           QString commentsFont,
@@ -47,6 +53,9 @@ public:
     QString getMinorFeedFont();
 
 
+    void syncColorSettings(QStringList newColorList);
+    QStringList getColorsList();
+
 
     void createMessageForContact(QString name, QString id);
     void editPost(QString originalPostId,
@@ -68,10 +77,15 @@ public slots:
 
 
 private:
+    int minorFeedSnippetsType;
+    int snippetsCharLimit;
+
     QString postTitleFontInfo;
     QString postContentsFontInfo;
     QString commentsFontInfo;
     QString minorFeedFontInfo;
+
+    QStringList colorsList;
 };
 
 #endif // GLOBALOBJECT_H
