@@ -26,7 +26,7 @@ ImageViewer::ImageViewer(QString fileURI,
                          bool isAnimated,
                          QWidget *parent) : QWidget(parent)
 {
-    this->setMinimumSize(420, 320);
+    this->setMinimumSize(460, 320);
 
     this->suggestedFilename = suggestedFN;
     this->imageIsAnimated = isAnimated;
@@ -66,7 +66,8 @@ ImageViewer::ImageViewer(QString fileURI,
                            + tr("ESC to close, secondary-click for options"));
 
 
-    saveImageButton = new QPushButton(QIcon::fromTheme("document-save-as"),
+    saveImageButton = new QPushButton(QIcon::fromTheme("document-save-as",
+                                                       QIcon(":/images/button-save.png")),
                                       tr("&Save As..."));
     connect(saveImageButton, SIGNAL(clicked()),
             this, SLOT(saveImage()));
@@ -138,16 +139,29 @@ ImageViewer::~ImageViewer()
 
 void ImageViewer::createContextMenu()
 {
-    contextMenu = new QMenu("imageViewerMenu");
+    this->saveAction = new QAction(QIcon::fromTheme("document-save-as",
+                                                    QIcon(":/images/button-save.png")),
+                                   tr("Save Image..."),
+                                   this);
+    saveAction->setShortcut(QKeySequence("Ctrl+S"));
+    connect(saveAction, SIGNAL(triggered()),
+            this, SLOT(saveImage()));
+
+    this->closeAction = new QAction(QIcon::fromTheme("window-close"),
+                                    tr("Close Viewer"),
+                                    this);
+    closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
+    connect(closeAction, SIGNAL(triggered()),
+            this, SLOT(close()));
 
 
-    contextMenu->addAction(QIcon::fromTheme("document-save-as"),
-                           tr("Save Image..."),
-                           this, SLOT(saveImage()));
-    contextMenu->addAction(QIcon::fromTheme("window-close"),
-                           tr("Close Viewer"),
-                           this,
-                           SLOT(close()));
+    this->contextMenu = new QMenu("imageViewerMenu");
+    contextMenu->addAction(saveAction);
+    contextMenu->addAction(closeAction);
+
+    // Make the shortcuts work
+    this->addAction(saveAction);
+    this->addAction(closeAction);
 }
 
 
@@ -246,18 +260,6 @@ void ImageViewer::resizeEvent(QResizeEvent *event)
 }
 
 
-void ImageViewer::keyPressEvent(QKeyEvent *event)
-{
-    if (event->key() == Qt::Key_Escape)
-    {
-        this->close();
-    }
-    else
-    {
-        event->accept();
-    }
-}
-
 
 void ImageViewer::contextMenuEvent(QContextMenuEvent *event)
 {
