@@ -153,7 +153,7 @@ void ListsManager::setListsList(QVariantList listsList)
         listDescription = listMap.value("content").toString();
         if (!listDescription.isEmpty())
         {
-            listDescription.append("<b></b>"); // HTMLize it so it gets wordwrapped
+            listDescription.prepend("<b></b>"); // HTMLize it so it gets wordwrapped
         }
 
         listMembersCount = listMap.value("members").toMap().value("totalItems").toString();
