@@ -35,7 +35,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     reallyQuitProgram = false;
     trayIconAvailable = false;
-    trayCurrentCount = 0;
+    trayCurrentNewCount = 0;
+    trayCurrentHLCount = 0;
 
 
     QString currentIconset = QIcon::themeName();
@@ -70,10 +71,6 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     mainSplitter->setContentsMargins(0, 0, 0, 0);
     mainSplitter->setHandleWidth(4);
 
-    // FIXME: disabled for 1.2.0
-    //connect(mainSplitter, SIGNAL(splitterMoved(int,int)),
-    //        this, SLOT(onSplitterMoved()));
-
 
 
     // Left side
@@ -432,6 +429,9 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     connect(pumpController, SIGNAL(authorizationFailed(QString,QString)),
             this, SLOT(showAuthError(QString,QString)));
 
+    connect(pumpController, SIGNAL(initializationComplete()),
+            this, SLOT(onInitializationComplete()));
+
 
     // After receiving timeline contents, update corresponding timeline
     connect(pumpController, SIGNAL(mainTimelineReceived(QVariantList,int,QString,QString,int)),
@@ -523,6 +523,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     settings.endGroup();
 
 
+    logViewer->addToLog(tr("Dianara started."));
+
     // If User ID is defined, set PumpController in motion
     if (!userID.isEmpty())
     {
@@ -532,7 +534,9 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     }
     else // Otherwise, just say so in the statusbar
     {
-        this->setStatusBarMessage(tr("Your account is not configured yet."));
+        QString message = tr("Your account is not configured yet.");
+        this->setStatusBarMessage(message);
+        logViewer->addToLog(message);
     }
 
     // Post-init timer
@@ -543,8 +547,6 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     postInitTimer->start(1000);
 
 
-    logViewer->addToLog(tr("Dianara started."));
-
     qDebug() << "MainWindow created";
 }
 
@@ -714,7 +716,17 @@ void MainWindow::createMenus()
             this, SLOT(updateAllTimelines()));
     sessionMenu->addAction(sessionUpdateAllTimelines);
 
-    sessionMenu->addSeparator();
+    sessionAutoUpdates = new QAction(QIcon::fromTheme("clock"),
+                                     tr("Auto-update &Timelines"),
+                                     this);
+    sessionAutoUpdates->setCheckable(true);
+    sessionAutoUpdates->setChecked(true);
+    sessionAutoUpdates->setDisabled(true); // until initialization is complete
+    connect(sessionAutoUpdates, SIGNAL(toggled(bool)),
+            this, SLOT(toggleAutoUpdates(bool)));
+    sessionMenu->addAction(sessionAutoUpdates);
+
+    sessionMenu->addSeparator(); // ------
 
     sessionMarkAllAsRead = new QAction(QIcon::fromTheme("mail-mark-read"),
                                        tr("Mark All as Read"),
@@ -813,6 +825,7 @@ void MainWindow::createMenus()
     settingsEditProfile = new QAction(QIcon::fromTheme("user-properties",
                                                        QIcon(":/images/no-avatar.png")),
                                       tr("Edit &Profile"), this);
+    settingsEditProfile->setShortcut(QKeySequence("Ctrl+Shift+P"));
     connect(settingsEditProfile, SIGNAL(triggered()),
             profileEditor, SLOT(show()));
     settingsMenu->addAction(settingsEditProfile);
@@ -825,8 +838,10 @@ void MainWindow::createMenus()
 
     settingsMenu->addSeparator();
 
-    settingsFilters = new QAction(QIcon::fromTheme("view-filter"),
+    settingsFilters = new QAction(QIcon::fromTheme("view-filter",
+                                                   QIcon(":/images/button-filter.png")),
                                   tr("&Filters and Highlighting"), this);
+    settingsFilters->setShortcut(QKeySequence("Ctrl+Shift+F"));
     connect(settingsFilters, SIGNAL(triggered()),
             filterEditor, SLOT(show()));
     settingsMenu->addAction(settingsFilters);
@@ -834,6 +849,7 @@ void MainWindow::createMenus()
     settingsConfigure = new QAction(QIcon::fromTheme("configure",
                                                      QIcon(":/images/button-configure.png")),
                                     tr("&Configure Dianara"), this);
+    settingsConfigure->setShortcut(QKeySequence("Ctrl+Shift+S"));
     connect(settingsConfigure, SIGNAL(triggered()),
             configDialog, SLOT(show()));
     settingsMenu->addAction(settingsConfigure);
@@ -891,7 +907,10 @@ void MainWindow::createMenus()
     this->menuBar()->setContextMenuPolicy(Qt::PreventContextMenu);
 
 
-    // Context menu for the tray icon
+    ///// Context menu for the tray icon
+    trayTitleSeparatorAction = new QAction("Dianara", this);
+    trayTitleSeparatorAction->setSeparator(true);
+
     trayShowWindowAction = new QAction(QIcon(":/icon/64x64/dianara.png"),
                                        "*show-window*", this);
     connect(trayShowWindowAction, SIGNAL(triggered()),
@@ -899,11 +918,13 @@ void MainWindow::createMenus()
 
     trayContextMenu = new QMenu("Tray Context Menu");
     trayContextMenu->setSeparatorsCollapsible(false);
-    trayContextMenu->addSeparator()->setText("Dianara");
+    trayContextMenu->addAction(trayTitleSeparatorAction); // Acts as title
     trayContextMenu->addAction(trayShowWindowAction);
     trayContextMenu->addSeparator();
     trayContextMenu->addAction(sessionUpdateMainTimeline);
     trayContextMenu->addAction(sessionUpdateMinorFeed);
+    trayContextMenu->addAction(sessionAutoUpdates);
+    trayContextMenu->addSeparator();
     trayContextMenu->addAction(sessionMarkAllAsRead);
     trayContextMenu->addAction(sessionPostNote);
     trayContextMenu->addSeparator();
@@ -934,7 +955,9 @@ void MainWindow::createToolbar()
     mainToolBar->addAction(this->sessionUpdateMinorFeed);
     mainToolBar->addAction(this->sessionMarkAllAsRead);
     mainToolBar->addSeparator();
+    this->settingsFilters->setPriority(QAction::LowPriority); // Don't show text in besides-icon mode
     mainToolBar->addAction(this->settingsFilters);
+    this->settingsConfigure->setPriority(QAction::LowPriority);
     mainToolBar->addAction(this->settingsConfigure);
 
 
@@ -944,6 +967,11 @@ void MainWindow::createToolbar()
 
 void MainWindow::createStatusbarWidgets()
 {
+    this->statusStateButton = new QToolButton();
+    this->setStateIcon(MainWindow::Initializing);
+    connect(statusStateButton, SIGNAL(clicked()),
+            sessionAutoUpdates, SLOT(toggle()));
+
     this->statusLogButton = new QToolButton();
     statusLogButton->setIcon(QIcon::fromTheme("text-x-log",
                                               QIcon(":/images/log.png")));
@@ -952,10 +980,37 @@ void MainWindow::createStatusbarWidgets()
             viewLogAction, SLOT(trigger()));
 
     this->statusBar()->addPermanentWidget(statusLogButton);
+    this->statusBar()->addPermanentWidget(statusStateButton);
     this->statusBar()->setSizeGripEnabled(false);
 }
 
 
+void MainWindow::setStateIcon(MainWindow::StatusType statusType)
+{
+    if (statusType == Initializing)
+    {
+        statusStateButton->setDisabled(true); // Until initialization is done
+        statusStateButton->setToolTip(tr("Initializing..."));
+        statusStateButton->setIcon(QIcon::fromTheme("user-offline",
+                                                    QIcon(":/images/button-offline.png")));
+    }
+    else if (statusType == Autoupdating)
+    {
+        statusStateButton->setEnabled(true);
+        statusStateButton->setToolTip("<b></b>" + tr("Auto-updating enabled"));
+        statusStateButton->setIcon(QIcon::fromTheme("user-online",
+                                                    QIcon(":/images/button-online.png")));
+    }
+    else // MainWindow::Stopped
+    {
+        statusStateButton->setEnabled(true);
+        statusStateButton->setToolTip("<b></b>" + tr("Auto-updating disabled"));
+        statusStateButton->setIcon(QIcon::fromTheme("user-busy",
+                                                    QIcon(":/images/button-busy.png")));
+    }
+}
+
+
 /*
  * Create an icon in the system tray, define its contextual menu, etc.
  *
@@ -1001,9 +1056,10 @@ void MainWindow::createTrayIcon()
  * Set the tray icon's pixmap, with number of unread messages, or nothing
  *
  */
-void MainWindow::setTrayIconPixmap(int count)
+void MainWindow::setTrayIconPixmap(int count, int hightlightedCount)
 {
-    this->trayCurrentCount = count;
+    this->trayCurrentNewCount = count;
+    this->trayCurrentHLCount = hightlightedCount;
 
     QPixmap iconPixmap;
 
@@ -1037,28 +1093,57 @@ void MainWindow::setTrayIconPixmap(int count)
 
 
     // Paint the number of unread messages on top of the pixmap, if != 0
-    if (count > 0)
+    if (trayCurrentNewCount > 0)
     {
-        QFont font;
-        font.setPixelSize(18);
-        font.setBold(true);
-
         // Draw a pseudo-shadow on the side first
         QPainter painter(&iconPixmap);
-        painter.drawPixmap(0, 0,
-                           32, 32,
-                           QPixmap(":/images/tray-bg.png"));
+        if (trayCurrentHLCount > 0)
+        {
+            // Paint a shadow that covers the higher part too
+            painter.drawPixmap(0, 0,
+                               32, 32,
+                               QPixmap(":/images/tray-bg-high.png"));
+        }
+        else
+        {
+            // Shadow for the lower part only
+            painter.drawPixmap(0, 0,
+                               32, 32,
+                               QPixmap(":/images/tray-bg-low.png"));
+        }
+
+        QFont font;
+        font.setPixelSize(16);
+        font.setWeight(QFont::Black);
+
+
+        // The number
+        QString messagesCountString = QString("%1").arg(trayCurrentNewCount);
 
         QPen pen;
-        font.setWeight(QFont::Black);
         pen.setBrush(Qt::white);
         painter.setFont(font);
         painter.setPen(pen);
         // Draw the number of new messages
         painter.drawText(0, 0,
-                         32, 32,
+                         32, 34,  // End painting outside, at Y=34, to skip margins
                          Qt::AlignRight | Qt::AlignBottom,
-                         QString("%1").arg(count));
+                         messagesCountString);
+
+        if (trayCurrentHLCount > 0)
+        {
+            // The other number
+            messagesCountString = QString("%1").arg(trayCurrentHLCount);
+
+            pen.setBrush(Qt::cyan);
+            painter.setPen(pen);
+
+            // Draw the number of highlighted messages
+            painter.drawText(0, -2,  // Start painting outside, at Y=-2, to avoid some margins
+                             32, 32,
+                             Qt::AlignRight | Qt::AlignTop,
+                             messagesCountString);
+        }
     }
 
     this->trayIcon->setIcon(iconPixmap);
@@ -1089,8 +1174,8 @@ void MainWindow::loadSettings()
     // Main window state
     settings.beginGroup("MainWindow");
 
-    this->resize(settings.value("windowSize", QSize(680, 560)).toSize());
-    if (!firstRun)
+    this->resize(settings.value("windowSize", QSize(740, 580)).toSize());
+    if (!firstRun) // So we should have a proper position saved
     {
         this->move(settings.value("windowPosition").toPoint());
     }
@@ -1225,20 +1310,7 @@ void MainWindow::updateConfigSettings()
                                          proxyUser,
                                          QString::fromLocal8Bit(proxyPassword));
 
-    // Timelines & MinorFeed colors
-    QStringList highlightColorsList;
-    highlightColorsList.append(settings.value("color1").toString());
-    highlightColorsList.append(settings.value("color2").toString());
-    highlightColorsList.append(settings.value("color3").toString());
-    highlightColorsList.append(settings.value("color4").toString());
-    highlightColorsList.append(settings.value("color5").toString());
-    highlightColorsList.append(settings.value("color6").toString());
 
-    this->meanwhileFeed->updateHighlightColors(highlightColorsList);
-    this->mainTimeline->updateHighlightColors(highlightColorsList);
-    this->directTimeline->updateHighlightColors(highlightColorsList);
-    this->activityTimeline->updateHighlightColors(highlightColorsList);
-    this->favoritesTimeline->updateHighlightColors(highlightColorsList);
 
     // System tray icon type and custom icon filename, if any
     this->trayIconType = settings.value("systrayIconType", 0).toInt();
@@ -1250,7 +1322,8 @@ void MainWindow::updateConfigSettings()
     }
     if (trayIconAvailable)
     {
-        this->setTrayIconPixmap(trayCurrentCount); // Sync icon
+        this->setTrayIconPixmap(trayCurrentNewCount,
+                                trayCurrentHLCount); // Sync icon
     }
 
     settings.endGroup();
@@ -1261,7 +1334,6 @@ void MainWindow::updateConfigSettings()
     qDebug() << "tabsPosition updated:" << tabsPosition << tabWidget->tabPosition();
     qDebug() << "tabsMovable updated:" << tabsMovable;
     qDebug() << "public posts updated:" << publicPosts;
-    qDebug() << "colors updated:" << highlightColorsList;
     qDebug() << "tray icon type updated:" << trayIconType;
 }
 
@@ -1291,6 +1363,22 @@ void MainWindow::toggleWidgetsByAuthorization(bool authorized)
 }
 
 
+void MainWindow::onInitializationComplete()
+{
+    this->sessionAutoUpdates->setEnabled(true);
+
+    if (this->sessionAutoUpdates->isChecked())
+    {
+        this->setStateIcon(MainWindow::Autoupdating);
+    }
+    else
+    {
+        this->setStateIcon(MainWindow::Stopped);
+    }
+
+}
+
+
 /*
  * Stuff executed 1 second after MainWindow is created
  *
@@ -1428,6 +1516,32 @@ void MainWindow::updateProfileData(QString avatarUrl, QString fullName,
                                         eMail);
 }
 
+/*
+ * Enable or disable the timer that auto-updates the timelines
+ *
+ */
+void MainWindow::toggleAutoUpdates(bool checked)
+{
+    QString message;
+
+    if (checked)
+    {
+        this->setStateIcon(MainWindow::Autoupdating);
+        this->updateTimer->start();
+        message = tr("Starting automatic update of timelines, "
+                     "once every %1 minutes.").arg(this->updateInterval);
+    }
+    else
+    {
+        this->setStateIcon(MainWindow::Stopped);
+        this->updateTimer->stop();
+        message = tr("Stopping automatic update of timelines.");
+    }
+
+    this->setStatusBarMessage(message);
+    this->logViewer->addToLog(message);
+}
+
 
 /*
  * Update all timelines
@@ -1589,8 +1703,12 @@ void MainWindow::notifyTimelineUpdate(int timelineType,
 
 
     // In either case, restart update timer, so every manual update of timeline
-    this->updateTimer->stop();  // will postpone the auto-update
-    this->updateTimer->start();
+    // will postpone the auto-update but ONLY IF autoupdates are enabled
+    if (this->sessionAutoUpdates->isChecked())
+    {
+        this->updateTimer->stop();
+        this->updateTimer->start();
+    }
 
     // And adjust timelines sizes
     this->adjustTimelineSizes();
@@ -1663,7 +1781,8 @@ void MainWindow::setTimelineTabTitle(int timelineType,
     {
         if (trayIconAvailable)
         {
-            this->setTrayIconPixmap(newPostCount);
+            this->setTrayIconPixmap(newPostCount,
+                                    highlightCount);
         }
     }
 
@@ -1700,15 +1819,28 @@ void MainWindow::setTitleAndTrayInfo(int currentTab)
     this->setWindowTitle(title);
     if (trayIconAvailable)
     {
+        QString idToShow = this->userID.isEmpty()
+                           ? tr("Your Pump.io account is not configured")
+                             : userID;
+#ifdef Q_OS_UNIX
         title = "<b>Dianara</b>: "
               + currentTabTitle
               + "<br><br>["
-              + (userID.isEmpty() ?
-                        tr("Your Pump.io account is not configured") : userID)
+              + idToShow
               + "]";
+#else
+        // Some OSes don't render HTML in the tray tooltip
+        title = "Dianara: "
+              + currentTabTitle
+              + "\n\n["
+              + idToShow
+              + "]";
+#endif
 
 
         this->trayIcon->setToolTip(title);
+
+        this->trayTitleSeparatorAction->setText("Dianara - " + this->userID);
     }
 }
 
@@ -1989,21 +2121,6 @@ void MainWindow::adjustTimelineSizes()
 }
 
 
-/*
- * Limit width of the meanwhile feed according to splitter movements
- *
- */
-void MainWindow::onSplitterMoved()
-{
-    // Prevent long, non-wrappable texts from making the minor feed too wide
-    this->meanwhileFeed->setMaximumWidth(mainSplitter->sizes().at(0) - 32);
-    // FIXME: this is disabled for 1.2.0
-
-    //adjustTimelineSizes();  // SLOW
-}
-
-
-
 
 
 /*
@@ -2113,7 +2230,7 @@ void MainWindow::visitUserList()
 void MainWindow::aboutDianara()
 {
     QMessageBox::about(this, tr("About Dianara"),
-                       "<b>Dianara v1.2.3</b><br>"
+                       "<b>Dianara v1.2.4</b><br>"
                        "Copyright 2012-2014  JanKusanagi<br><br>"
                        "<a href=\"http://jancoding.wordpress.com/dianara\">"
                        "http://jancoding.wordpress.com/dianara</a><br><br>"
@@ -2139,7 +2256,12 @@ void MainWindow::aboutDianara()
 
                        + tr("Dianara is licensed under the GNU GPL license, and "
                             "uses some Oxygen icons: http://www.oxygen-icons.org/ "
-                            "(LGPL licensed)"));
+                            "(LGPL licensed)")
+                       + "<br><br>"
+                         "<a href=\"http://www.gnu.org/licenses/gpl-2.0.html\">"
+                         "GNU GPL v2</a> - "
+                         "<a href=\"http://www.gnu.org/licenses/lgpl-2.1.html\">"
+                         "GNU LGPL v2.1</a>");
 
 
     if (this->isHidden()) // FIXME: ugly workaround to avoid closing the program
@@ -2220,8 +2342,30 @@ void MainWindow::quitProgram()
 
     if (reallyQuitProgram)
     {
+        std::cout << "\nShutting down Dianara ("
+                     + this->userID.toStdString()
+                     + ")...\n";
+        std::cout.flush();
+
+        // Manually remove some stuff; trying to minimize shutdown time
+        this->mainTimeline->clearTimeLineContents();
+        this->directTimeline->clearTimeLineContents();
+        this->activityTimeline->clearTimeLineContents();
+        this->favoritesTimeline->clearTimeLineContents();
+        this->meanwhileFeed->clearContents();
+
+        this->publisher->deleteLater();
+        this->contactManager->deleteLater();
+
+        qApp->processEvents(QEventLoop::ExcludeUserInputEvents
+                          | QEventLoop::ExcludeSocketNotifiers);
+
         qApp->closeAllWindows();
-        qDebug() << "All windows closed, bye!";
+        //qApp->quit();
+
+        //qApp->processEvents();
+        std::cout << "All windows closed, bye! o/\n";
+        std::cout.flush();
     }
 }
 
@@ -2238,6 +2382,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 {
     qDebug() << "MainWindow::closeEvent()";
 
+    // FIXME: handle cases where tray icon isn't available
 
     if (reallyQuitProgram)
     {
