@@ -63,10 +63,6 @@ MinorFeed::MinorFeed(PumpController *pumpController,
     this->setLayout(mainLayout);
 
 
-    // Set the 6 colors empty, on start, since they're required when creating the demo
-    // item feed, and they're not set at this point yet
-    highlightColorsList << "" << "" << "" << "" << "" << "";
-
 
     // Demo activity, stating that there's nothing to show
     QVariantMap demoGenerator;
@@ -81,7 +77,6 @@ MinorFeed::MinorFeed(PumpController *pumpController,
     ASActivity *demoActivity = new ASActivity(demoActivityMap, this);
 
     MinorFeedItem *demoFeedItem = new MinorFeedItem(demoActivity,
-                                                    this->highlightColorsList,
                                                     false, // Not highlighted by filter
                                                     this->pController,
                                                     this->globalObj);
@@ -113,11 +108,6 @@ MinorFeed::~MinorFeed()
 }
 
 
-void MinorFeed::updateHighlightColors(QStringList colorList)
-{
-    highlightColorsList = colorList;
-}
-
 
 void MinorFeed::clearContents()
 {
@@ -199,21 +189,19 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
     {
         this->clearContents();
         this->newItemsCount = 0;
+        this->newHighlightedItemsCount = 0;
     }
 
     // Process event queue, so GUI can get updated
     qApp->processEvents(); // This also acts as "scroll to top", incidentally
 
 
-
     bool itemHighlightedByFilter;
     bool itemIsNew;    
     bool allNewItemsCounted = false;
     QString newestActivityId; // To store the activity ID for the newest item in the feed
                               // so we can know how many new items we receive next time
 
-    newHighlightedItemsCount = 0;
-
 
     foreach (QVariant activityVariant, activitiesList)
     {
@@ -273,7 +261,6 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
             }
 
             MinorFeedItem *newFeedItem = new MinorFeedItem(activity,
-                                                           this->highlightColorsList,
                                                            itemHighlightedByFilter,
                                                            this->pController,
                                                            this->globalObj);
@@ -300,9 +287,16 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
 
 
     this->previousNewestActivityId = newestActivityId;
-    emit newItemsCountChanged(newItemsCount, newHighlightedItemsCount);
-    emit newItemsReceived(newItemsCount, newHighlightedItemsCount);
-    qDebug() << "Meanwhile feed updated; New items:" << newItemsCount;
+
+    qDebug() << "Meanwhile feed updated";
+    if (this->feedOffset == 0) // not when getting more
+    {
+        emit newItemsCountChanged(newItemsCount, newHighlightedItemsCount);
+        emit newItemsReceived(newItemsCount, newHighlightedItemsCount);
+        qDebug() << "New items:" << newItemsCount
+                 << "; Highlighted:" << newHighlightedItemsCount;
+    }
+
 
     this->getMoreButton->show();
     this->getMoreButton->setEnabled(true);
