@@ -48,7 +48,6 @@ public:
                        QWidget *parent = 0);
     ~MinorFeed();
 
-    void updateHighlightColors(QStringList colorList);
     void clearContents();
     void markAllAsRead();
     void updateFuzzyTimestamps();
@@ -86,7 +85,6 @@ private:
 
     QFrame *separatorFrame;
 
-    QStringList highlightColorsList;
 
     PumpController *pController;
     GlobalObject *globalObj;
