@@ -22,7 +22,6 @@
 
 
 MinorFeedItem::MinorFeedItem(ASActivity *activity,
-                             QStringList highlightColors,
                              bool highlightedByFilter,
                              PumpController *pumpController,
                              GlobalObject *globalObject,
@@ -101,101 +100,8 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     this->setFuzzyTimeStamp();
 
 
-    /////////////////////////// Tooltip contents
-    QString activityTooltip;
-
-    // Object's author name and ID
-    QString activityObjectAuthorName = activity->object()->author()->getName();
-    QString activityObjectAuthorId = activity->object()->author()->getId();
-    if (activityObjectAuthorName.isEmpty())
-    {
-        activityObjectAuthorName = activityObjectAuthorId;
-    }
-
-    // If there's a name and/or an ID, show them
-    if (!activityObjectAuthorName.isEmpty())
-    {
-        activityTooltip = "<b>" + activityObjectAuthorName + "</b><br>"
-                          "<i>" + activityObjectAuthorId + "</i>"
-                          "<hr><br>"; // horizontal rule as separator
-    }
-
-
-    // Title
-    QString activityObjectTitle = activity->object()->getTitle();
-    if (activityObjectTitle.isEmpty())
-    {
-        activityTooltip.append("<b></b>");
-    }
-    else
-    {
-        activityTooltip.append("<b><u>" + activityObjectTitle + "</u></b><br>");
-    }
-
-    // Content
-    QString activityObjectContent = activity->object()->getContent();
-    if (!activityObjectContent.isEmpty())
-    {
-        activityTooltip.append(activityObjectContent + "<br>");
-    }
-
-    // Object ID, interesting to show if it's a person
-    if (activity->object()->getType() == "person")
-    {
-        activityTooltip.append("<br><i>"
-                               + activity->object()->getId()
-                               + "</i><br><br>");
-    }
-
-
-    // Target info
-    QString activityTargetName = activity->target()->getTitle();
-    QString activityTargetUrl = activity->target()->getUrl();
-    if (activityTargetUrl.isEmpty())
-    {
-        activityTargetUrl = activity->target()->getId();
-    }
-    if (!activityTargetUrl.isEmpty())
-    {
-        activityTooltip.append("<hr>&gt;&gt; "); // Horizontal rule, and >>
-
-        if (!activityTargetName.isEmpty())
-        {
-            activityTooltip.append(QString("<b>%1</b>"
-                                           "<br><i>%2</i>")
-                                   .arg(activityTargetName)
-                                   .arg(activityTargetUrl));
-        }
-        else
-        {
-            activityTooltip.append("<i>" + activityTargetUrl + "</i>");
-        }
-    }
-
-
-    // Remove last <br>, if needed
-    if (activityTooltip.endsWith("<br>"))
-    {
-        activityTooltip.remove(-4, 4);
-        // Check again, for double <br>'s
-        if (activityTooltip.endsWith("<br>"))
-        {
-            activityTooltip.remove(-4, 4);
-        }
-    }
-
-    activityTooltip = activityTooltip.trimmed();
-
-    // If the tooltip is only this, remove it / FIXME
-    if (activityTooltip == "<b></b>")
-    {
-        activityTooltip.clear();
-    }
-
-
-    activityDescriptionLabel = new QLabel(activity->getContent());
-                                          // + " &nbsp;");  // FIXME 1.2.4?
-                                          // + " <br>");
+    // The description itself, like "JaneDoe updated a note",
+    activityDescriptionLabel = new QLabel(); // To be filled later
     QFont descriptionFont;
     descriptionFont.fromString(globalObj->getMinorFeedFont());
     activityDescriptionLabel->setFont(descriptionFont);
@@ -207,10 +113,12 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     connect(activityDescriptionLabel, SIGNAL(linkHovered(QString)),
             this, SLOT(showUrlInfo(QString)));
 
+    // Tooltip contents
+    QString activityTooltip = activity->generateTooltip();
     if (!activityTooltip.isEmpty())
     {
-        // Set the activity info as tooltip for the whole widget, not only the label
-        this->setToolTip(activityTooltip);
+        // Set the activity info as tooltip for description label
+        this->activityDescriptionLabel->setToolTip(activityTooltip);
 
         // Set a different mouse cursor for the description label, as a hint to wait for tooltip info
         this->activityDescriptionLabel->setCursor(Qt::WhatsThisCursor);
@@ -227,6 +135,7 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
     // Highlight this item if it's about the user, with different colors
     itemHighlightType = -1; // False
+    QStringList highlightColors = globalObj->getColorsList();
     QString highlightItemColor;
 
     // We are in the recipient list of the activity
@@ -311,6 +220,35 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     }
 
 
+    // Set the activity description with optional snippet
+    QString activityDescription = activity->getContent();
+
+
+    // Add a snippet if configured to do so
+    if (this->globalObj->getMinorFeedSnippetsType() != 3) // 3=Never
+    {
+        if (this->globalObj->getMinorFeedSnippetsType() == 2 // 2=Always
+         || this->itemHighlightType != -1)       // 0/1/2 and it's highlighted
+        {
+            if (this->globalObj->getMinorFeedSnippetsType() > 0  // Always or any highlighted
+             || authorId != pController->currentUserId())        // or highlighted but not ours (0)
+            {
+                // FIXME: fix this spaghetti mess!!
+                // TODO: option to not show when the object of the activity is ours
+                // i.e. "JohnDoe liked a note", our note
+
+                QString snippet = activity->generateSnippet(globalObj->getSnippetsCharLimit());
+                if (!snippet.isEmpty())
+                {
+                    activityDescription.append("&nbsp;<hr>" + snippet);
+                }
+            }
+        }
+    }
+
+    this->activityDescriptionLabel->setText(activityDescription);
+
+
 
 
     ////// Layout
@@ -319,23 +257,10 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     leftLayout->addWidget(avatarButton, 1, Qt::AlignTop | Qt::AlignLeft);
 
 
-    bool canDisplayObject = false;
-    QString activityObjectType = activity->object()->getType();
-    if (activityObjectType == "note"
-     || activityObjectType == "article"
-     || activityObjectType == "image"
-     || activityObjectType == "audio"
-     || activityObjectType == "video"
-     || activityObjectType == "file"
-     || activityObjectType == "comment"
-     || activityObjectType == "group")
-    {
-        canDisplayObject = true;
-    }
 
     // Original post available (inReplyTo) or object available (note, image...)
     if (!inReplyToMap.isEmpty()
-        || (canDisplayObject
+        || (this->canDisplayObject(activity->object()->getType())
             && activity->object()->getDeletedTime().isEmpty())
        )
     {
@@ -460,6 +385,36 @@ int MinorFeedItem::getItemHighlightType()
 }
 
 
+/*
+ * Returns true if objectType is one of the types that Post() can display
+ *
+ * FIXME: this should probably be moved to the Post class
+ *
+ */
+bool MinorFeedItem::canDisplayObject(QString objectType)
+{
+    bool canDisplay = false;
+
+    if (objectType == "note"
+     || objectType == "article"
+     || objectType == "image"
+     || objectType == "audio"
+     || objectType == "video"
+     || objectType == "file"
+     || objectType == "comment"
+     || objectType == "group")
+    {
+        canDisplay = true;
+    }
+    else
+    {
+        qDebug() << "MinorFeedItem::canDisplayObject() - Unsupported:"
+                 << objectType;
+    }
+
+    return canDisplay;
+}
+
 
 
 /****************************************************************************/
@@ -467,6 +422,7 @@ int MinorFeedItem::getItemHighlightType()
 /****************************************************************************/
 
 
+
 void MinorFeedItem::openOriginalPost()
 {
     // Create a fake activity for the object
@@ -484,11 +440,7 @@ void MinorFeedItem::openOriginalPost()
 
     ASActivity *originalPostActivity = new ASActivity(originalPostMap, this);
 
-    QStringList colorsList;
-    colorsList << "" << "" << "" << "" << "" << ""; // Empty color list, needs 6 colors to avoid crashes
-
     Post *referencedPost = new Post(originalPostActivity,
-                                    colorsList,
                                     false, // Not highlighted
                                     true,  // Post is standalone
                                     pController,
