@@ -45,7 +45,6 @@ class MinorFeedItem : public QFrame
 
 public:
     explicit MinorFeedItem(ASActivity *activity,
-                           QStringList highlightColors,
                            bool highlightedByFilter,
                            PumpController *pumpController,
                            GlobalObject *globalObject,
@@ -56,6 +55,9 @@ public:
     void setFuzzyTimeStamp();
 
     int getItemHighlightType();
+
+    static bool canDisplayObject(QString objectType);
+
     
 signals:
     void itemRead(bool wasHighlighted);
@@ -65,10 +67,12 @@ public slots:
     void openOriginalPost();
     void showUrlInfo(QString url);
 
+
 protected:
     virtual void mousePressEvent(QMouseEvent *event);
     virtual void leaveEvent(QEvent *event);
 
+
 private:
     PumpController *pController;
     GlobalObject *globalObj;
