@@ -21,7 +21,6 @@
 #include "post.h"
 
 Post::Post(ASActivity *activity,
-           QStringList highlightColors,
            bool highlightedByFilter,
            bool isStandalone,
            PumpController *pumpController,
@@ -37,7 +36,7 @@ Post::Post(ASActivity *activity,
     this->postImageIsAnimated = false; // Initialize
     this->setSizePolicy(QSizePolicy::MinimumExpanding,
                         QSizePolicy::Minimum);
-    this->setMinimumSize(10, 10); // Ensure something's visible at all times
+    this->setMinimumSize(30, 30); // Ensure something's visible at all times
 
     activity->setParent(this); // reparent the passed activity
 
@@ -46,6 +45,7 @@ Post::Post(ASActivity *activity,
 
     ///////////////////////////////////////////////// Highlighting
     this->highlightType = NoHighlight;
+    QStringList highlightColors = globalObj->getColorsList();
     QString highlightPostColor;
 
     // Post is adressed to us
@@ -98,42 +98,7 @@ Post::Post(ASActivity *activity,
 
     this->postId = activity->object()->getId();
     this->postType = activity->object()->getType();
-    QString postTypeString;
-    if (postType == "note")
-    {
-        postTypeString = tr("Note");
-    }
-    else if (postType == "image")
-    {
-        postTypeString = tr("Image");
-    }
-    else if (postType == "audio")
-    {
-        postTypeString = tr("Audio");
-    }
-    else if (postType == "video")
-    {
-        postTypeString = tr("Video");
-    }
-    else if (postType == "file")
-    {
-        postTypeString = tr("File");
-    }
-    else if (postType == "group")
-    {
-        postTypeString = tr("Group");
-    }
-    else if (postType == "comment")
-    {
-        postTypeString = tr("Comment",
-                            "Noun, as in object type: a comment");
-    }
-    else
-    {
-        postTypeString = tr("Other",
-                            "As in: other type of post")
-                         + " (" + postType + ")";
-    }
+    QString postTypeString = activity->object()->getTranslatedType(postType);
 
     this->postUrl = activity->object()->getUrl();
 
@@ -150,16 +115,11 @@ Post::Post(ASActivity *activity,
         authorPerson = activity->author();
     }
     this->postAuthorId = authorPerson->getId();
-    this->postAuthorName = authorPerson->getName();
-    // In case there's no name to show, for some reason, use ID
-    if (postAuthorName.isEmpty()) // This happens sometimes with shared objects
-    {
-        postAuthorName = postAuthorId;
-    }
+    this->postAuthorName = authorPerson->getNameWithFallback();
 
 
     // Save post title for openClickedURL(), editPost() etc
-    this->postTitle = activity->object()->getTitle().trimmed();
+    this->postTitle = activity->object()->getTitle();
 
     QString generator = activity->getGenerator();
 
@@ -170,13 +130,14 @@ Post::Post(ASActivity *activity,
         QString windowTitle = tr("Post", "Noun, not verb")
                               + ": " + postTypeString + " - Dianara";
         this->setWindowTitle(windowTitle);
-        this->setWindowFlags(Qt::Window);
+        this->setWindowFlags(Qt::Dialog);
         this->setWindowModality(Qt::WindowModal);
 
         // Restore size
         this->setMinimumSize(420, 360);
         QSettings settings;
-        this->resize(settings.value("Post/postSize").toSize());
+        this->resize(settings.value("Post/postSize",
+                                    QSize(600, 440)).toSize());
     }
 
     postIsUnread = false;
@@ -197,8 +158,11 @@ Post::Post(ASActivity *activity,
         this->postSharedById = activity->getSharedById();
 
         QString sharedByName = MiscHelpers::fixLongName(activity->getSharedByName());
-        postIsSharedLabel->setText(QString::fromUtf8("\342\231\272  ") // Recycling symbol
-                                   + tr("Via %1").arg(sharedByName));
+        postIsSharedLabel->setText("<p>"
+                                   + QString::fromUtf8("\342\231\272  ") // Recycling symbol
+                                   + tr("Via %1").arg(sharedByName)
+                                   + QString::fromUtf8("  \342\231\272")
+                                   + "</p> &nbsp;");
         postIsSharedLabel->setWordWrap(true);
         postIsSharedLabel->setAlignment(Qt::AlignCenter);
         postIsSharedLabel->setFont(detailsFont);
@@ -206,12 +170,19 @@ Post::Post(ASActivity *activity,
         postIsSharedLabel->setBackgroundRole(QPalette::Base);
         postIsSharedLabel->setAutoFillBackground(true);
         postIsSharedLabel->setFrameStyle(QFrame::Panel | QFrame::Raised);
+        postIsSharedLabel->setSizePolicy(QSizePolicy::Ignored,
+                                         QSizePolicy::Expanding);
+
 
         sharedByTooltipString = "<img align=\"left\" src=\""
                                 + MiscHelpers::getCachedAvatarFilename(activity->getSharedByAvatar())
                                 + "\" width=\"48\" />";
-        sharedByTooltipString.append("&nbsp;&nbsp;<b>" + sharedByName + "</b><br>");
-        sharedByTooltipString.append("&nbsp;&nbsp;<i>" + this->postSharedById + "</i>");
+        sharedByTooltipString.append("&nbsp;&nbsp;<b>"
+                                     + sharedByName
+                                     + "</b><br>");
+        sharedByTooltipString.append("&nbsp;&nbsp;<i>"
+                                     + this->postSharedById
+                                     + "</i>");
 
         shareTime = activity->getUpdatedAt();
         QString exactShareTime = Timestamp::localTimeDate(shareTime);
@@ -290,6 +261,23 @@ Post::Post(ASActivity *activity,
             this, SLOT(normalizeTextFormat()));
     postAuthorAvatarButton->addActionToMenu(normalizeTextAction);
 
+
+    if (standalone) // own window, add close option to menu
+    {
+        // -----
+        postAuthorAvatarButton->addSeparatorToMenu();
+
+        this->closeAction = new QAction(QIcon::fromTheme("window-close"),
+                                        tr("&Close"),
+                                        this);
+        connect(closeAction, SIGNAL(triggered()),
+                this, SLOT(close()));
+        postAuthorAvatarButton->addActionToMenu(closeAction);
+    }
+
+
+    // End avatar menu
+
     leftColumnLayout->addWidget(postAuthorAvatarButton, 0, Qt::AlignLeft);
     leftColumnLayout->addSpacing(2);
 
@@ -347,13 +335,11 @@ Post::Post(ASActivity *activity,
                                       .arg(Timestamp::localTimeDate(postUpdatedAtString)));
     }
 
-    postCreatedAtLabel = new QLabel();
+    postCreatedAtLabel = new HClabel();
     postCreatedAtLabel->setToolTip(dateGeneratorTooltip);
     postCreatedAtLabel->setTextFormat(Qt::PlainText);
-    postCreatedAtLabel->setWordWrap(true);
     postCreatedAtLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postCreatedAtLabel->setFont(detailsFont);
-    postCreatedAtLabel->setAutoFillBackground(true);
     leftColumnLayout->addWidget(postCreatedAtLabel);
     leftColumnLayout->addSpacing(4);
 
@@ -361,9 +347,8 @@ Post::Post(ASActivity *activity,
     QString location = activity->object()->getLocationName();
     if (!location.isEmpty())
     {
-        this->postLocationLabel = new QLabel(tr("In")
-                                             + ": <b>" + location + "</b>");
-        postLocationLabel->setWordWrap(true);
+        this->postLocationLabel = new HClabel(tr("In")
+                                              + ": <b>" + location + "</b>");
         postLocationLabel->setFont(detailsFont);
         postLocationLabel->setToolTip(activity->object()->getLocationTooltip());
         leftColumnLayout->addWidget(postLocationLabel);
@@ -377,6 +362,8 @@ Post::Post(ASActivity *activity,
         postToLabel->setWordWrap(true);
         postToLabel->setFont(detailsFont);
         postToLabel->setOpenExternalLinks(true);
+        postToLabel->setSizePolicy(QSizePolicy::Ignored,
+                                   QSizePolicy::Minimum);
 
         leftColumnLayout->addWidget(postToLabel);
         connect(postToLabel, SIGNAL(linkHovered(QString)),
@@ -390,6 +377,8 @@ Post::Post(ASActivity *activity,
         postCCLabel->setWordWrap(true);
         postCCLabel->setFont(detailsFont);
         postCCLabel->setOpenExternalLinks(true);
+        postCCLabel->setSizePolicy(QSizePolicy::Ignored,
+                                   QSizePolicy::Minimum);
 
         leftColumnLayout->addWidget(postCCLabel);
         connect(postCCLabel, SIGNAL(linkHovered(QString)),
@@ -407,8 +396,7 @@ Post::Post(ASActivity *activity,
     // Set this QLabels with parent=this, since we're gonna hide them right away
     // They'll be reparented to the layout, but not having a parent before that
     // would cause visual glitches
-    postLikesCountLabel = new QLabel(this);
-    postLikesCountLabel->setWordWrap(true);
+    postLikesCountLabel = new HClabel("", this);
     postLikesCountLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postLikesCountLabel->setFont(detailsFont);
     leftColumnLayout->addWidget(postLikesCountLabel);
@@ -427,8 +415,7 @@ Post::Post(ASActivity *activity,
     this->setCommentsLabel(commentsCount);
 
 
-    postResharesCountLabel = new QLabel(this);
-    postResharesCountLabel->setWordWrap(true);
+    postResharesCountLabel = new HClabel("", this);
     postResharesCountLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postResharesCountLabel->setFont(detailsFont);
     leftColumnLayout->addWidget(postResharesCountLabel);
@@ -460,13 +447,30 @@ Post::Post(ASActivity *activity,
         openParentPostButton->setFont(buttonsFont);
         openParentPostButton->setSizePolicy(QSizePolicy::Ignored,
                                             QSizePolicy::Maximum);
-        openParentPostButton->setToolTip(tr("Open the parent post, to which "
-                                            "this one replies"));
+        openParentPostButton->setToolTip("<b></b>"
+                                         + tr("Open the parent post, to which "
+                                              "this one replies"));
         connect(openParentPostButton, SIGNAL(clicked()),
                 this, SLOT(openParentPost()));
         leftColumnLayout->addWidget(openParentPostButton);
     }
 
+    // If showing standalone, add a Close button; needed in some environments
+    // Button disabled for now; added option to avatar menu
+#if 0
+    if (standalone)
+    {
+        this->closeButton = new QPushButton(QIcon::fromTheme("window-close"),
+                                            tr("&Close"));
+        closeButton->setFont(buttonsFont);
+        closeButton->setSizePolicy(QSizePolicy::Ignored,
+                                   QSizePolicy::Maximum);
+        connect(closeButton, SIGNAL(clicked()),
+                this, SLOT(close()));
+
+        leftColumnLayout->addWidget(closeButton);
+    }
+#endif
 
     leftColumnFrame->setLayout(leftColumnLayout);
 
@@ -510,7 +514,7 @@ Post::Post(ASActivity *activity,
     postText->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postText->setSizePolicy(QSizePolicy::MinimumExpanding,
                             QSizePolicy::MinimumExpanding);
-
+    postText->setMinimumSize(10, 10);
     postText->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
     postText->setOpenLinks(false); // don't open links, manage in openClickedURL()
     postText->setReadOnly(true); // it's default with QTextBrowser, but still...
@@ -560,7 +564,8 @@ Post::Post(ASActivity *activity,
                                                          QIcon(":/images/button-comment.png")),
                                         tr("Comment",
                                            "verb, for the comment button"));
-        commentButton->setToolTip(tr("Reply to this post.") + "<br>"
+        commentButton->setToolTip(tr("Reply to this post.")
+                                  + "<br>"
                                   + tr("If you select some text, it will be quoted."));
         commentButton->setFlat(true);
         commentButton->setFont(buttonsFont);
@@ -580,14 +585,16 @@ Post::Post(ASActivity *activity,
             || (pController->currentUserId() != this->postSharedById))
         {
             shareButton->setText(tr("Share"));
-            shareButton->setToolTip(tr("Share this post with your contacts"));
+            shareButton->setToolTip("<b></b>"
+                                    + tr("Share this post with your contacts"));
             connect(shareButton, SIGNAL(clicked()),
                     this, SLOT(sharePost()));
         }
         else // Shared by us!
         {
             shareButton->setText(tr("Unshare"));
-            shareButton->setToolTip(tr("Unshare this post"));
+            shareButton->setToolTip("<b></b>"
+                                    + tr("Unshare this post"));
             connect(shareButton, SIGNAL(clicked()),
                     this, SLOT(unsharePost()));
             shareButton->setDisabled(true); // FIXME: disabled for 1.2.x, since it doesn't really work
@@ -602,7 +609,8 @@ Post::Post(ASActivity *activity,
         editButton = new QPushButton(QIcon::fromTheme("document-edit",
                                                       QIcon(":/images/button-edit.png")),
                                      tr("Edit"));
-        editButton->setToolTip(tr("Modify this post"));
+        editButton->setToolTip("<b></b>"
+                               + tr("Modify this post"));
         editButton->setFlat(true);
         editButton->setFont(buttonsFont);
         connect(editButton, SIGNAL(clicked()),
@@ -612,7 +620,8 @@ Post::Post(ASActivity *activity,
         deleteButton = new QPushButton(QIcon::fromTheme("edit-delete",
                                                         QIcon(":/images/button-delete.png")),
                                        tr("Delete"));
-        deleteButton->setToolTip(tr("Erase this post"));
+        deleteButton->setToolTip("<b></b>"
+                                 + tr("Erase this post"));
         deleteButton->setFlat(true);
         deleteButton->setFont(buttonsFont);
         connect(deleteButton, SIGNAL(clicked()),
@@ -735,7 +744,6 @@ Post::Post(ASActivity *activity,
             this, SLOT(getAllComments()));
     rightColumnLayout->addWidget(commenter,     0);
 
-    rightColumnLayout->addStretch(0); // Use remaining space when there are no comments
     rightColumnFrame->setLayout(rightColumnLayout);
 
     // Set the initial likes, comments and shares (4 most recent)
@@ -749,8 +757,8 @@ Post::Post(ASActivity *activity,
 
     mainLayout = new QHBoxLayout();
     mainLayout->setContentsMargins(0, 0, 0, 0);   // Minimal margins
-    mainLayout->addWidget(leftColumnFrame,   2);  // stretch 2/12
-    mainLayout->addWidget(rightColumnFrame, 10);  // stretch 10/12
+    mainLayout->addWidget(leftColumnFrame,   2);  // stretch 2/13
+    mainLayout->addWidget(rightColumnFrame, 11);  // stretch 11/13
 
     mainLayout->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     this->setLayout(mainLayout);
@@ -765,14 +773,14 @@ Post::Post(ASActivity *activity,
     this->setFuzzyTimestamps();
 
 
-    qDebug() << "Post created" << this->postUrl;
+    qDebug() << "Post created" << this->postId;
 }
 
 
 
 Post::~Post()
 {
-    qDebug() << "Post destroyed" << this->postUrl;
+    qDebug() << "Post destroyed" << this->postId;
 }
 
 
@@ -781,7 +789,8 @@ Post::~Post()
 void Post::setMinMaxHeight(int newMinMaxHeight)
 {
     // Substract some pixels to account for the row of buttons, etc.
-    this->minMaxHeight = newMinMaxHeight - 80;
+    this->minMaxHeight = qMax(newMinMaxHeight - 80,
+                              50);
 }
 
 
@@ -884,6 +893,15 @@ void Post::setPostContents()
 }
 
 
+void Post::onResizeOrShow()
+{
+    this->postWidth = qMax(postText->width() - 80,   // FIXME: use viewport?
+                           50);                      // minimum width of 50
+
+    this->setPostContents();
+}
+
+
 
 /*
  * Set the height of the post, based on the contents
@@ -891,17 +909,10 @@ void Post::setPostContents()
  */
 void Post::setPostHeight()
 {
-    int height = postText->document()->size().toSize().height() + 12; // +12px error margin
+    int height = qMax(postText->document()->size().toSize().height() + 12, // +12px error margin
+                      60); // Minimum height of 60
 
-    if (height < 60)
-    {
-        height = 60;
-    }
-
-    if (height > this->minMaxHeight)  // Don't allow a post to be too tall
-    {
-        height = this->minMaxHeight;  // Scrollbars might appear
-    }
+    height = qMin(height, this->minMaxHeight); // Don't allow a post to be too tall
 
     // Don't force a specific height if the post is standalone
     if (!standalone)
@@ -958,11 +969,17 @@ void Post::setLikes(QVariantList likesList, int likesCount)
 {
     if (likesList.size() > 0)
     {
-        QString peopleString;
+        QString peopleString; // FIXME: repeated in Comment(), move to method
         foreach (QVariant likesMap, likesList)
         {
-            peopleString = likesMap.toMap().value("displayName").toString() + ", "
-                           + peopleString;
+            QString name = likesMap.toMap().value("displayName").toString();
+            if (name.isEmpty())
+            {
+                name = ASPerson::cleanupId(likesMap.toMap()
+                                                   .value("id")
+                                                   .toString()); // fallback
+            }
+            peopleString.append(name + ", ");
         }
 
         // Remove last comma and add "like this"
@@ -979,7 +996,7 @@ void Post::setLikes(QVariantList likesList, int likesCount)
             likesString = tr("%1 like this",
                              "More than one person").arg(peopleString);
         }
-        likesString.append("<b></b>"); // Turn the tooltip into rich text
+        likesString.prepend("<b></b>"); // Turn the tooltip into rich text
 
         this->postLikesCountLabel->setToolTip(likesString);
     }
@@ -1127,7 +1144,7 @@ void Post::setShares(QVariantList sharesList, int sharesCount)
         {
             sharesString = tr("%1 shared this", "%1 = Names for more than one person").arg(peopleString);
         }
-        sharesString.append("<a></a>");  // So that the label is rich text
+        sharesString.prepend("<b></b>");  // So that the label is rich text, wordwrapped
 
         this->postResharesCountLabel->setToolTip(sharesString);
     }
@@ -1193,14 +1210,7 @@ void Post::setPostUnreadStatus()
 
     if (this->postIsUnread)
     {
-        postCreatedAtLabel->setStyleSheet("QLabel "
-                                          "{ color: palette(highlighted-text);   "
-                                          "  background-color: palette(highlight)"
-                                          "}"
-                                          "QLabel:hover "
-                                          "{ color: palette(text);               "
-                                          "  background-color: palette(highlight)"
-                                          "}");
+        postCreatedAtLabel->setHighlighted(true);
 
         if (!css.isEmpty())
         {
@@ -1214,10 +1224,7 @@ void Post::setPostUnreadStatus()
     }
     else
     {
-        postCreatedAtLabel->setStyleSheet("QLabel "
-                                          "{ background-color: transparent }"
-                                          "QLabel:hover "
-                                          "{ background-color: palette(highlight) }");
+        postCreatedAtLabel->setHighlighted(false);
 
         rightColumnFrame->setStyleSheet("");
 
@@ -1322,13 +1329,15 @@ void Post::fixLikeButton(QString state)
 {
     if (state == "true")
     {
-        likeButton->setToolTip(tr("You like this"));
+        likeButton->setToolTip("<b></b>"
+                               + tr("You like this"));
         likeButton->setText(tr("Unlike"));
         likeButton->setChecked(true);
     }
     else
     {
-        likeButton->setToolTip(tr("Like this post"));
+        likeButton->setToolTip("<b></b>"
+                               + tr("Like this post"));
         likeButton->setText(tr("Like"));
         likeButton->setChecked(false);
     }
@@ -1347,16 +1356,21 @@ void Post::getAllLikes()
 /*
  * Make the commenter widget visible, so user can type the comment
  *
+ * If some text was selected, insert it as quoted text
+ *
  */
 void Post::commentOnPost()
 {
-    qDebug() << "Commenting on this post";
+    qDebug() << "Commenting on post" << this->postTitle << this->postId;
 
     QString initialText;
 
     QString selectedText = this->postText->textCursor().selectedText();
     if (!selectedText.isEmpty())
     {
+        // Selected text has literal < and >, so convert to HTML entities
+        selectedText.replace("<", "&lt;");
+        selectedText.replace(">", "&gt;");
         initialText = MiscHelpers::quotedText(this->postAuthorName,
                                               selectedText);
     }
@@ -1580,12 +1594,7 @@ void Post::openParentPost()
 
     ASActivity *originalPostActivity = new ASActivity(fakeActivityMap, this);
 
-    QStringList colorsList;
-    colorsList << "" << "" << ""
-               << "" << "" << ""; // Empty color list, needs 6 colors to avoid crashes
-
     Post *parentPost = new Post(originalPostActivity,
-                                colorsList,
                                 false, // Not highlighted
                                 true,  // Post is standalone
                                 pController,
@@ -1632,8 +1641,8 @@ void Post::normalizeTextFormat()
  */
 void Post::triggerResize()
 {
-    this->resize(this->width() -1,
-                 this->height() -1);
+    this->resize(this->width() - 1,
+                 this->height() - 1);
 }
 
 
@@ -1678,12 +1687,9 @@ void Post::resizeEvent(QResizeEvent *event)
         return;
     }
 
-    this->postWidth = postText->width() - 80; // FIXME: use viewport?
-    if (postWidth < 50)
-    {
-        postWidth = 50;  // minimum width!
-    }
-    setPostContents();
+
+    this->onResizeOrShow();
+
 
     // Standalone mode doesn't need this kind of protection, and is not re-set by Timeline()
     if (!standalone)
@@ -1707,6 +1713,23 @@ void Post::mousePressEvent(QMouseEvent *event)
     event->accept();
 }
 
+void Post::keyPressEvent(QKeyEvent *event)
+{
+    if (event->key() == Qt::Key_Escape)
+    {
+        event->accept();
+
+        if (standalone)
+        {
+            this->close();
+        }
+    }
+    else
+    {
+        event->ignore();
+    }
+}
+
 
 /*
  * Ensure we change back the highlighted URL message when the mouse leaves the post
@@ -1732,27 +1755,34 @@ void Post::closeEvent(QCloseEvent *event)
         settings.setValue("Post/postSize", this->size());
     }
 
-    this->hide();
-    this->deleteLater();
+    if (this->commenter->isFullMode())
+    {
+        // Ask composer to cancel post, which asks the user, unless empty
+        this->commenter->getComposer()->cancelPost();
+    }
 
-    event->ignore();
+    event->ignore(); // Event will be ignored anyway
+
+
+    // Check again; if it's still full, it means user canceled
+    if (!this->commenter->isFullMode()) // If not, accepted, so kill the post
+    {
+        this->hide();
+        this->deleteLater();
+    }
 }
 
-
-void Post::keyPressEvent(QKeyEvent *event)
+/*
+ * Needed when a post is shown as a standalone window,
+ * to ensure images are properly resized
+ *
+ */
+void Post::showEvent(QShowEvent *event)
 {
-    if (event->key() == Qt::Key_Escape)
+    if (standalone)
     {
-        event->accept();
+        this->onResizeOrShow();
+    }
 
-        if (standalone)
-        {
-            this->close();
-        }
-    }
-    else
-    {
-        event->ignore();
-    }
+    event->accept();
 }
-
