@@ -25,8 +25,6 @@
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QTextBrowser>
-//#include <QTextBlock>
-//#include <QAbstractTextDocumentLayout>
 #include <QLabel>
 #include <QIcon>
 #include <QPixmap>
@@ -52,6 +50,7 @@
 #include "asactivity.h"
 #include "avatarbutton.h"
 #include "downloadwidget.h"
+#include "hclabel.h"
 
 
 class Post : public QFrame
@@ -60,7 +59,6 @@ class Post : public QFrame
 
 public:
     Post(ASActivity *activity,
-         QStringList highlightColors,
          bool highlightedByFilter,
          bool isStandalone,
          PumpController *pumpController,
@@ -72,6 +70,7 @@ public:
     void setMinMaxHeight(int newMinMaxHeight);
 
     void setPostContents();
+    void onResizeOrShow();
     void setPostHeight();
     void resetResizesCount();
     void getPendingImages();
@@ -149,9 +148,10 @@ public slots:
 protected:
     virtual void resizeEvent(QResizeEvent *event);
     virtual void mousePressEvent(QMouseEvent *event);
+    virtual void keyPressEvent(QKeyEvent *event);
     virtual void leaveEvent(QEvent *event);
     virtual void closeEvent(QCloseEvent *event);
-    virtual void keyPressEvent(QKeyEvent *event);
+    virtual void showEvent(QShowEvent *event);
 
 
 private:
@@ -182,20 +182,22 @@ private:
     QAction *openPostInBrowserAction;
     QAction *copyPostUrlAction;
     QAction *normalizeTextAction;
+    QAction *closeAction;
 
     QLabel *postAuthorNameLabel;
-    QLabel *postCreatedAtLabel;
-    QLabel *postLocationLabel;
+    HClabel *postCreatedAtLabel;
+    HClabel *postLocationLabel;
     QLabel *postToLabel;
     QLabel *postCCLabel;
     QLabel *postIsSharedLabel;
 
-    QLabel *postLikesCountLabel;
+    HClabel *postLikesCountLabel;
     QLabel *postCommentsCountLabel;
-    QLabel *postResharesCountLabel;
+    HClabel *postResharesCountLabel;
 
     QPushButton *openParentPostButton;
 
+    //QPushButton *closeButton;
 
     QLabel *postTitleLabel;
     QLabel *postSummaryLabel;
