@@ -26,9 +26,9 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
 {
     this->setWindowTitle(tr("Profile Editor") + " - Dianara");
     this->setWindowIcon(QIcon::fromTheme("user-properties"));
-    this->setWindowFlags(Qt::Window);
-    this->setWindowModality(Qt::NonModal);
-    this->setMinimumSize(500, 350);
+    this->setWindowFlags(Qt::Dialog);
+    this->setWindowModality(Qt::ApplicationModal);
+    this->setMinimumSize(500, 400);
 
     this->pController = pumpController;
 
@@ -44,9 +44,10 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     emailLabel = new QLabel();
     emailLabel->setFont(infoFont);
     emailLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
-    emailLabel->setToolTip(tr("This is the e-mail address associated with your account, "
-                              "for things such as notifications and password recovery")
-                           + "<b></b>"); // Make the tooltip HTML so it gets wordwrap
+    emailLabel->setToolTip("<b></b>" // Make the tooltip HTML so it gets wordwrap
+                           + tr("This is the e-mail address associated with "
+                                "your account, for things such as "
+                                "notifications and password recovery"));
 
 
     avatarLabel = new QLabel();
@@ -63,7 +64,9 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
 
     fullNameLineEdit = new QLineEdit();
     fullNameLineEdit->setToolTip(tr("This is your visible name"));
+
     hometownLineEdit = new QLineEdit();
+
     bioTextEdit = new QTextEdit();
     bioTextEdit->setTabChangesFocus(true);
     bioTextEdit->setSizePolicy(QSizePolicy::MinimumExpanding,
@@ -93,10 +96,11 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     // Layout
     this->avatarLayout = new QHBoxLayout();
     avatarLayout->addWidget(avatarLabel);
+    avatarLayout->addSpacing(16);
     avatarLayout->addWidget(changeAvatarButton);
 
+
     this->topLayout = new QFormLayout();
-    topLayout->setVerticalSpacing(8);
     topLayout->addRow(tr("Webfinger ID"), webfingerLabel);
     topLayout->addRow(tr("E-mail"),       emailLabel);
 
@@ -105,6 +109,8 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     topLayout->addRow(tr("Full &Name"),   fullNameLineEdit);
     topLayout->addRow(tr("&Hometown"),    hometownLineEdit);
     topLayout->addRow(tr("&Bio"),         bioTextEdit);
+    // FIXME: the FormLayout doesn't let the bioTextField row grow taller than its sizeHint()
+
 
     this->bottomLayout = new QHBoxLayout();
     bottomLayout->setAlignment(Qt::AlignRight | Qt::AlignBottom);
@@ -117,6 +123,7 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     mainLayout->addLayout(bottomLayout);
     this->setLayout(mainLayout);
 
+
     // Disable some stuff until profile is received
     this->toggleWidgetsEnabled(false);
 
@@ -213,9 +220,10 @@ void ProfileEditor::findAvatarFile()
         this->newAvatarContentType = MiscHelpers::getFileMimeType(newAvatarFilename);
         if (!avatarPixmap.isNull() && !newAvatarContentType.isEmpty())
         {
-            this->avatarLabel->setPixmap(QPixmap(newAvatarFilename).scaled(64, 64,
-                                                                           Qt::KeepAspectRatio,
-                                                                           Qt::SmoothTransformation));
+            this->avatarLabel->setPixmap(QPixmap(newAvatarFilename)
+                                         .scaled(64, 64,
+                                                 Qt::KeepAspectRatio,
+                                                 Qt::SmoothTransformation));
             this->avatarChanged = true;
         }
         else
