@@ -29,7 +29,7 @@ ProxyDialog::ProxyDialog(int proxyType,
 {
     this->setWindowTitle(tr("Proxy Configuration") + " - Dianara");
     this->setWindowIcon(QIcon::fromTheme("preferences-system-network"));
-    this->setWindowFlags(Qt::Window);
+    this->setWindowFlags(Qt::Dialog);
     this->setWindowModality(Qt::WindowModal);
     this->setMinimumSize(380, 320);
 
