@@ -58,8 +58,8 @@ Publisher::Publisher(PumpController *pumpController,
             this, SLOT(updateToCcFields(QString,QStringList)));
 
 
-    QString titleTooltip = tr("Setting a title helps make the Meanwhile feed "
-                              "more informative") + "<b></b>";
+    QString titleTooltip = "<b></b>" + tr("Setting a title helps make the "
+                                          "Meanwhile feed more informative");
 
     QFont titleFont;
     titleFont.setBold(true);
@@ -193,12 +193,16 @@ Publisher::Publisher(PumpController *pumpController,
     toAudienceLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     toAudienceLabel->setFont(audienceLabelsFont);  // Normal
     toAudienceLabel->setWordWrap(true);
+    connect(toAudienceLabel, SIGNAL(linkHovered(QString)),
+            this, SLOT(showHighlightedUrl(QString)));
 
     ccAudienceLabel = new QLabel();
     ccAudienceLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     audienceLabelsFont.setItalic(true);
     ccAudienceLabel->setFont(audienceLabelsFont);  // Italic
     ccAudienceLabel->setWordWrap(true);
+    connect(ccAudienceLabel, SIGNAL(linkHovered(QString)),
+            this, SLOT(showHighlightedUrl(QString)));
 
     // And these will show "public" or "followers" current selection (in bold)
     toPublicFollowersLabel = new QLabel();
@@ -941,11 +945,16 @@ void Publisher::updateToCcFields(QString selectorType,
     {
         contactRE.indexIn(contactString);
 
-        // FIXME: make links to each profile here
-        addressesString.append(contactRE.cap(1).trimmed());
+        // FIXME: make links to each profile here -- WIP
+        QString contactAddress = contactRE.cap(2).trimmed();
+        //QString contactUrl = contactAddress.split("@").last() + "/" + ...;
+
+        addressesString.append("<a href=\"" + contactAddress + "\">"
+                               + contactRE.cap(1).trimmed()
+                               + "</a>");
         addressesString.append(", ");
 
-        addressesStringList.append(contactRE.cap(2).trimmed());
+        addressesStringList.append(contactAddress);
     }
     addressesString.remove(-2, 2); // remove ", " at the end
 
@@ -1058,6 +1067,26 @@ void Publisher::updateCcListsFields(QAction *listAction)
 }
 
 
+/*
+ * Show the URL of a contact in the recipients list, in the status bar
+ *
+ * FIXME: merge with Post::showHighlightedUrl()
+ *
+ */
+void Publisher::showHighlightedUrl(QString url)
+{
+    if (!url.isEmpty())
+    {
+        this->pController->showTransientMessage(url);
+        qDebug() << "Highlighted recipient url in publisher:" << url;
+    }
+    else
+    {
+        this->pController->showTransientMessage("");
+    }
+}
+
+
 
 
 /*
@@ -1202,13 +1231,38 @@ void Publisher::findMediaFile()
                                             mediaTypes
                                             + tr("All files") + " (*)");
 
-
     if (!filename.isEmpty())
     {
         qDebug() << "Selected" << filename << "for upload";
-
+        QFileInfo fileInfo(filename);
         this->mediaContentType = MiscHelpers::getFileMimeType(filename);
-        if (!mediaContentType.isEmpty())
+
+        // Temporary protection; https://github.com/e14n/pump.io/issues/1015
+        if (fileInfo.size() > 10485760) // 10 MiB; this protects the servers from abuse
+        {
+            QString bigImageNote;
+            if (postType == "image")
+            {
+                bigImageNote = "\n\n"
+                               + tr("Since you're uploading an image, you could "
+                                    "scale it down a little or save it in a "
+                                    "more compressed format, like JPG.");
+            }
+
+            QMessageBox::warning(this, tr("File is too big"),
+                                 tr("Dianara currently limits file uploads "
+                                    "to 10 MiB per post, to prevent possible "
+                                    "storage or network problems in the "
+                                    "servers.")
+                                 + "\n\n"
+                                 + tr("This is a temporary measure, since "
+                                      "the servers cannot set their "
+                                      "own limits yet.")
+                                 + bigImageNote
+                                 + "\n\n"
+                                 + tr("Sorry for the inconvenience."));
+        }
+        else if (!mediaContentType.isEmpty())
         {
             this->pictureLabel->setToolTip(filename);
             this->mediaFilename = filename;
@@ -1229,7 +1283,7 @@ void Publisher::findMediaFile()
                                          .arg(imagePixmap.width())
                                          .arg(imagePixmap.height());
             }
-            QFileInfo fileInfo(filename);
+
             this->lastUsedDirectory = fileInfo.path();
             qDebug() << "last used directory:" << lastUsedDirectory;
 
