@@ -22,7 +22,7 @@
 
 PumpController::PumpController(QObject *parent) :  QObject(parent)
 {
-    this->userAgentString = "Dianara/1.2.3";
+    this->userAgentString = "Dianara/1.2.4";
 
     this->postsPerPageMain = 20;
     this->postsPerPageOther = 10;
@@ -216,6 +216,12 @@ void PumpController::setUserCredentials(QString userID)
     {
         this->initialDataTimer->start(2000);  // start 2 seconds after setting the ID
                                               // (mainly on program startup)
+        emit logMessage(tr("Authorized to use account %1. Getting initial data.")
+                        .arg(this->userId));
+    }
+    else
+    {
+        emit logMessage(tr("There is no authorized account."));
     }
 }
 
@@ -440,7 +446,6 @@ void PumpController::getContactList(QString listType, int offset)
     QNetworkRequest contactListRequest;
     if (listType == "following")
     {
-        emit currentJobChanged(tr("Getting list of 'Following'..."));
         contactListRequest = this->prepareRequest(url, QOAuth::GET,
                                                   FollowingListRequest,
                                                   paramMap);
@@ -448,11 +453,11 @@ void PumpController::getContactList(QString listType, int offset)
         {
             totalReceivedFollowing = 0;
             followingIdList.clear();
+            this->showStatusMessageAndLogIt(tr("Getting list of 'Following'..."));
         }
     }
     else
     {
-        emit currentJobChanged(tr("Getting list of 'Followers'..."));
         contactListRequest = this->prepareRequest(url, QOAuth::GET,
                                                   FollowersListRequest,
                                                   paramMap);
@@ -460,6 +465,7 @@ void PumpController::getContactList(QString listType, int offset)
         {
             totalReceivedFollowers = 0;
         }
+        this->showStatusMessageAndLogIt(tr("Getting list of 'Followers'..."));
     }
 
     nam.get(contactListRequest);
@@ -1131,8 +1137,7 @@ QNetworkReply *PumpController::uploadFile(QString filename,
                                           QString contentType,
                                           int uploadType)
 {
-    qDebug() << "PumpController::uploadFile()";
-
+    qDebug() << "PumpController::uploadFile()" << filename << contentType;
     QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/uploads";
 
     QNetworkRequest postRequest = this->prepareRequest(url, QOAuth::POST,
@@ -1145,13 +1150,11 @@ QNetworkReply *PumpController::uploadFile(QString filename,
     QByteArray data = file.readAll();  // FIXME: This can use a lot of RAM with big files
     file.close();
 
-    QString prettyLogMessage = tr("Uploading %1",
-                                  "1=filename").arg(filename)
-                               + QString(" (%1, %2)")
-                                 .arg(contentType)
-                                 .arg(MiscHelpers::fileSizeString(filename));
-    emit currentJobChanged(prettyLogMessage);
-    emit logMessage(prettyLogMessage);
+    this->showStatusMessageAndLogIt(tr("Uploading %1",
+                                       "1=filename").arg(filename)
+                                    + QString(" (%1, %2)")
+                                      .arg(contentType)
+                                      .arg(MiscHelpers::fileSizeString(filename)));
 
     return nam.post(postRequest, data);
 }
@@ -1218,6 +1221,13 @@ void PumpController::showTransientMessage(QString message)
 }
 
 
+void PumpController::showStatusMessageAndLogIt(QString message)
+{
+    emit currentJobChanged(message);
+    emit logMessage(message);
+}
+
+
 
 /***************************************************************************/
 /***************************************************************************/
@@ -1423,7 +1433,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
     case 0: // Other kinds of network errors
         errorTypeString = tr("Error connecting to %1").arg(replyHost);
         emit currentJobChanged(errorTypeString + ": " + replyErrorString);
-        emit logMessage(errorTypeString + ": " + replyErrorString);
+        emit logMessage(errorTypeString + ": " + replyErrorString, replyUrl);
 
         qDebug() << "Error connecting to" << replyHost;
         return;
@@ -1501,12 +1511,9 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
         if (jsonParsedOK && jsonData.size() > 0)
         {
-            prettyLogMessage = tr("Profile received.");
-            emit currentJobChanged(prettyLogMessage);
-            emit logMessage(prettyLogMessage);
+            this->showStatusMessageAndLogIt(tr("Profile received."));
 
             QVariantMap profileMap = jsonData["profile"].toMap();
-
             if (profileMap.value("id").toString() == "acct:" + this->userId)
             {
                 qDebug() << "Received OWN profile; keys:" << profileMap.keys();
@@ -1544,7 +1551,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
 
     case UpdateProfileRequest:
-        emit currentJobChanged(tr("Profile updated."));
+        this->showStatusMessageAndLogIt(tr("Profile updated."));
         this->getUserProfile(this->userId);
 
         break;
@@ -1620,15 +1627,13 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
     ////////////////////////////////////
     case PublishPostRequest:
-        prettyLogMessage = tr("Post published successfully.");
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
+        this->showStatusMessageAndLogIt(tr("Post published successfully."));
         if (jsonParsedOK && jsonData.size() > 0)
         {
             qDebug() << "JSON parsed OK";
 
-            QString objectID = jsonData["object"].toMap().value("id").toString();
-            qDebug() << "Post ID:" << objectID;
+            QString objectId = jsonData["object"].toMap().value("id").toString();
+            qDebug() << "Post ID:" << objectId;
 
             QString objectType = jsonData["object"].toMap().value("objectType").toString();
             if (objectType == "image"
@@ -1637,7 +1642,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
              || objectType == "file")
             {
                 // Update the object with title and description
-                this->postMediaStepThree(objectID);
+                this->postMediaStepThree(objectId);
             }
             else
             {
@@ -1657,9 +1662,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
 
     case PublishAvatarRequest:
-        prettyLogMessage = tr("Avatar published successfully.");
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
+        this->showStatusMessageAndLogIt(tr("Avatar published successfully."));
         if (jsonParsedOK && jsonData.size() > 0)
         {
             qDebug() << "JSON parsed OK";
@@ -1688,17 +1691,13 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
     ////////////////////////////////////
     case UpdatePostRequest:
-        prettyLogMessage = tr("Post updated successfully.");
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
+        this->showStatusMessageAndLogIt(tr("Post updated successfully."));
 
         emit postPublished();
         break;
 
     case UpdateCommentRequest:
-        prettyLogMessage = tr("Comment updated successfully.");
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
+        this->showStatusMessageAndLogIt(tr("Comment updated successfully."));
 
         emit commentPosted();
         break;
@@ -1708,9 +1707,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
     ///////////////////////////////////// If liking a post was requested
     case LikePostRequest:
-        prettyLogMessage = tr("Message liked or unliked successfully.");
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
+        this->showStatusMessageAndLogIt(tr("Message liked or unliked successfully."));
 
         emit likeSet();
         break;
@@ -1741,9 +1738,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
     ///////////////////////////////////// If commenting on a post was requested
     case CommentPostRequest:
-        prettyLogMessage = tr("Comment posted successfully.");
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
+        this->showStatusMessageAndLogIt(tr("Comment posted successfully."));
 
         emit commentPosted(); // This will be caught by Commenter()
 
@@ -1758,10 +1753,21 @@ void PumpController::requestFinished(QNetworkReply *reply)
         if (jsonParsedOK && jsonData.size() > 0)
         {
             qDebug() << "JSON parsed OK";
-            emit currentJobChanged(tr("Comments received."));
-
             jsonDataList = jsonData["items"].toList();
-            qDebug() << "Number of items in comments list:" << jsonDataList.size();
+
+            int commentCount = jsonDataList.size();
+            qDebug() << "Number of items in comments list:" << commentCount;
+
+            if (commentCount == 1)
+            {
+                emit currentJobChanged(tr("1 comment received.")
+                                       .arg(commentCount));
+            }
+            else
+            {
+                emit currentJobChanged(tr("%1 comments received.")
+                                       .arg(commentCount));
+            }
 
             emit commentsReceived(jsonDataList, replyUrl);
         }
@@ -1775,9 +1781,21 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
 
     case SharePostRequest:
-        prettyLogMessage = tr("Post shared successfully.");
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
+        qDebug() << "Post shared OK";
+
+        if (jsonParsedOK && jsonData.size() > 0)
+        {
+            // FIXME: this should be done using ASActivity+ASObject
+            QVariantMap authorMap = jsonData.value("object").toMap().value("author").toMap();
+            QString authorName = authorMap.value("displayName").toString();
+            if (authorName.isEmpty())
+            {
+                authorName = ASPerson::cleanupId(authorMap.value("id").toString());
+            }
+            this->showStatusMessageAndLogIt(tr("Post by %1 shared successfully.",
+                                               "1=author of the post we are sharing")
+                                            .arg(authorName));
+        }
 
         break;
 
@@ -1814,9 +1832,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
 
     case DeletePostRequest:
-        prettyLogMessage = tr("Message deleted successfully.");
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
+        this->showStatusMessageAndLogIt(tr("Message deleted successfully."));
 
         break;
 
@@ -1848,8 +1864,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
                 emit contactUnfollowed(contact);
             }
 
-            emit currentJobChanged(prettyLogMessage);
-            emit logMessage(prettyLogMessage);
+            this->showStatusMessageAndLogIt(prettyLogMessage);
         }
 
         break;
@@ -1880,10 +1895,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
                     if (totalReceivedFollowing >= this->userFollowingCount)
                     {
                         this->haveFollowing = true;
-                        const QString followingOkString = tr("List of 'following' "
-                                                             "completely received.");
-                        emit currentJobChanged(followingOkString);
-                        emit logMessage(followingOkString);
+                        this->showStatusMessageAndLogIt(tr("List of 'following' "
+                                                           "completely received."));
                     }
                     else
                     {
@@ -1902,10 +1915,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
                     if (totalReceivedFollowers >= this->userFollowersCount)
                     {
                         this->haveFollowers = true;
-                        const QString followersOkString = tr("List of 'followers' "
-                                                             "completely received.");
-                        emit currentJobChanged(followersOkString);
-                        emit logMessage(followersOkString);
+                        this->showStatusMessageAndLogIt(tr("List of 'followers' "
+                                                           "completely received."));
                     }
                     else
                     {
@@ -1964,22 +1975,17 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
     // Person list created OK
     case CreatePersonListRequest:
-        prettyLogMessage = tr("Person list '%1' created successfully.")
-                           .arg(jsonData.value("object").toMap()
-                                        .value("displayName").toString());
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
+        this->showStatusMessageAndLogIt(tr("Person list '%1' created successfully.")
+                                        .arg(jsonData.value("object").toMap()
+                                                     .value("displayName").toString()));
 
         this->getListsList(); // And reload the person lists (FIXME!)
         break;
 
 
-    // Person list created OK
+    // Person list deleted OK
     case DeletePersonListRequest:
-        prettyLogMessage = tr("Person list deleted successfully.");
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
-
+        this->showStatusMessageAndLogIt(tr("Person list deleted successfully."));
 
         this->getListsList(); // And reload the person lists (FIXME!)
         break;
@@ -1995,7 +2001,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
             QVariant personListVariant = jsonData.value("items");
             if (personListVariant.type() == QVariant::List)
             {
-                qDebug() << "Parsed a List, listing people in list...";
+                qDebug() << "Parsed a List, listing people in list..."
+                         << jsonData.value("displayName");
 
                 emit currentJobChanged(tr("Person list received."));
                 emit personListReceived(personListVariant.toList(),
@@ -2030,12 +2037,10 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
             emit personAddedToList(personId, personName, personAvatar);
 
-            prettyLogMessage = tr("%1 (%2) added to list successfully.",
-                                  "1=contact name, 2=contact ID")
-                               .arg(personName)
-                               .arg(personId);
-            emit currentJobChanged(prettyLogMessage);
-            emit logMessage(prettyLogMessage);
+            this->showStatusMessageAndLogIt(tr("%1 (%2) added to list successfully.",
+                                               "1=contact name, 2=contact ID")
+                                            .arg(personName)
+                                            .arg(personId));
         }
         break;
 
@@ -2051,35 +2056,29 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
             emit personRemovedFromList(personId);
 
-            prettyLogMessage = tr("%1 (%2) removed from list successfully.",
-                                  "1=contact name, 2=contact ID")
-                               .arg(personName)
-                               .arg(personId);
-            emit currentJobChanged(prettyLogMessage);
-            emit logMessage(prettyLogMessage);
+            this->showStatusMessageAndLogIt(tr("%1 (%2) removed from list successfully.",
+                                               "1=contact name, 2=contact ID")
+                                            .arg(personName)
+                                            .arg(personId));
         }
         break;
 
 
     //////////////////////////////////////////////////////////////////// Groups
     case CreateGroupRequest:
-        prettyLogMessage = tr("Group %1 created successfully.")
-                             .arg(jsonData.value("object").toMap()
-                                          .value("displayName").toString());
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
-        qDebug() << "Group created; ==========================";
-        qDebug() << "ID:" << jsonData.value("object").toMap().value("id").toString();
+        this->showStatusMessageAndLogIt(tr("Group %1 created successfully.")
+                                        .arg(jsonData.value("object").toMap()
+                                                     .value("displayName").toString()));
 
+        qDebug() << "Group created; ID:" << jsonData.value("object").toMap()
+                                                    .value("id").toString();
         break;
 
 
     case JoinGroupRequest:
-        prettyLogMessage = tr("Group %1 joined successfully.")
-                             .arg(jsonData.value("object").toMap()
-                                          .value("displayName").toString());
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
+        this->showStatusMessageAndLogIt(tr("Group %1 joined successfully.")
+                                        .arg(jsonData.value("object").toMap()
+                                                     .value("displayName").toString()));
 
         qDebug() << "Group joined; ==========================";
         qDebug() << "Keys: " << jsonData.keys();
@@ -2089,11 +2088,9 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
 
     case LeaveGroupRequest:
-        prettyLogMessage = tr("Left the %1 group successfully.")
-                             .arg(jsonData.value("object").toMap()
-                                          .value("displayName").toString());
-        emit currentJobChanged(prettyLogMessage);
-        emit logMessage(prettyLogMessage);
+        this->showStatusMessageAndLogIt(tr("Left the %1 group successfully.")
+                                        .arg(jsonData.value("object").toMap()
+                                                     .value("displayName").toString()));
 
         break;
 
@@ -2131,9 +2128,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
         qDebug() << "Received MEDIA data, from " << replyUrl;
         if (finished)
         {
-            prettyLogMessage = tr("File downloaded successfully.");
-            emit currentJobChanged(prettyLogMessage);
-            emit logMessage(prettyLogMessage, replyUrl);
+            this->showStatusMessageAndLogIt(tr("File downloaded successfully."));
 
             emit downloadCompleted(replyUrl);
 
@@ -2170,7 +2165,8 @@ void PumpController::requestFinished(QNetworkReply *reply)
             {
                 if (requestType == UploadMediaForPostRequest)
                 {
-                    prettyLogMessage = tr("File uploaded successfully. Posting message...");
+                    prettyLogMessage = tr("File uploaded successfully. "
+                                          "Posting message...");
                     emit currentJobChanged(prettyLogMessage);
                     emit logMessage(prettyLogMessage, replyUrl);
 
@@ -2178,7 +2174,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
                 }
                 else if (requestType == UploadAvatarRequest)
                 {
-                    emit currentJobChanged(tr("Avatar uploaded."));
+                    this->showStatusMessageAndLogIt(tr("Avatar uploaded."));
                     this->postAvatarStepTwo(uploadedFileId);
                 }
             }
@@ -2242,10 +2238,11 @@ void PumpController::getToken()
         qDebug() << "PumpController::getToken()";
         qDebug() << "We do not have client_id/client_secret yet; doing Dynamic Client Registration";
 
-        // POST to https://hotpump.net/api/client/register, f.e.
+        this->showStatusMessageAndLogIt(tr("The application is not registered with "
+                                           "your server yet. Registering..."));
+
+        // POST to https://yourserver.example/api/client/register
         QNetworkRequest postRequest(QUrl("https://" + this->serverURL + "/api/client/register"));
-
-
         postRequest.setHeader(QNetworkRequest::ContentTypeHeader, "application/json");
         postRequest.setRawHeader("User-Agent", userAgentString);
         postRequest.setAttribute(QNetworkRequest::User,
@@ -2272,12 +2269,15 @@ void PumpController::getToken()
         // 2. asking the User to authorize the Request Token,
         // 3. exchanging the Request Token for the Access Token
 
-        qDebug() << "Doing OAuth token stuff...";
 
+        this->showStatusMessageAndLogIt(tr("Getting OAuth token..."));
+
+        qDebug() << "Doing OAuth token stuff...";
         qDebug() << "NOTE: if you see a crash here, you need QCA and its openSSL plugin:";
         qDebug() << ">> qca2-plugin-openssl, libqca2-plugin-ossl, or similar";
         qDebug() << "If you compiled Dianara from source, check the INSTALL file carefully";
 
+
         QStringList QCAsupportedFeatures = QCA::supportedFeatures();
         qDebug() << "QCA Supported Features:" << QCAsupportedFeatures;
 
@@ -2325,7 +2325,7 @@ void PumpController::getToken()
             tokenSecret = reply.value(QOAuth::tokenSecretParameterName());
 
             qDebug() << "Token:" << token;
-            qDebug() << "Token Secret:" << tokenSecret;
+            qDebug() << "Token Secret:" << tokenSecret.left(5) + "********** (hidden)";
 
             QUrl oAuthAuthorizeURL("https://" + this->serverURL + "/oauth/authorize");
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
@@ -2383,6 +2383,8 @@ void PumpController::authorizeApplication(QString verifierCode)
 
         this->isApplicationAuthorized = true;
 
+        this->showStatusMessageAndLogIt(tr("Application authorized successfully."));
+
         QSettings settings;
         settings.setValue("isApplicationAuthorized", this->isApplicationAuthorized);
         settings.setValue("token",       this->token);
@@ -2395,6 +2397,7 @@ void PumpController::authorizeApplication(QString verifierCode)
     }
     else
     {
+        this->showStatusMessageAndLogIt(tr("OAuth error while authorizing application."));
         qDebug() << "OAuth error while authorizing application" << qoauth->error();
     }
 
@@ -2448,66 +2451,90 @@ void PumpController::getInitialData()
         break;
 
     case 1:
-        if (!haveFollowing && haveProfile)
+        // Ensure we have the profile already, before getting contact lists...
+        if (!haveProfile)
         {
-            this->getContactList("following");
+            initialDataStep = -1; // Restart initialization!
+            this->showStatusMessageAndLogIt(tr("Still waiting for profile. "
+                                               "Trying again..."));
         }
         break;
 
     case 2:
-        if (!haveFollowers && haveProfile)
+        if (!haveFollowing)
         {
-            this->getContactList("followers");
+            if (haveProfile) // Require profile first, since it provides followingCount
+            {
+                this->getContactList("following");
+            }
+            else
+            {
+                --initialDataStep; // go back 1 to retry
+            }
         }
         break;
 
     case 3:
-        // Just some extra time to get 'following' before timelines
+        if (!haveFollowers)
+        {
+            if (haveProfile) // Required for followersCount
+            {
+                this->getContactList("followers");
+            }
+            else
+            {
+                --initialDataStep; // retry
+            }
+        }
         break;
 
     case 4:
+        // Just some extra time to get 'following' before timelines
+        break;
+
+    case 5:
         if (!haveMainTL)
         {
             this->getMainTimeline(0);
         }
         break;
 
-    case 5:
+    case 6:
         if (!haveMinorFeed)
         {
             this->getMinorFeed();
         }
         break;
 
-    case 6:
+    case 7:
         if (!havePersonLists)
         {
             this->getListsList();
         }
         break;
 
-    case 7:
+    case 8:
         if (!haveDirectTL)
         {
             this->getDirectTimeline(0);
         }
         break;
 
-    case 8:
+    case 9:
         if (!haveActivityTL)
         {
             this->getActivityTimeline(0);
         }
         break;
 
-    case 9:
+    case 10:
         if (!haveFavoritesTL)
         {
             this->getFavoritesTimeline(0);
         }
         break;
 
-    case 10:
+    case 11:
         // If some data is still missing, go back to the beginning of the cycle
         if (!haveProfile || !haveFollowing || !haveFollowers
          || !havePersonLists || !haveMainTL || !haveMinorFeed
@@ -2519,32 +2546,28 @@ void PumpController::getInitialData()
             {
                 initialDataStep = -1;
                 ++initialDataAttempts;
-                const QString restartString = tr("Some initial data was not "
-                                                 "received. Restarting "
-                                                 "initialization.");
-                emit currentJobChanged(restartString);
-                emit logMessage(restartString);
+
+                this->showStatusMessageAndLogIt(tr("Some initial data was not "
+                                                   "received. Restarting "
+                                                   "initialization.")
+                                                + QString(" (%1)")
+                                                  .arg(initialDataAttempts));
             }
             else
             {
-                const QString giveUpString = tr("Some initial data was not "
-                                                "received after several "
-                                                "attempts. Something might "
-                                                "be wrong with your server. "
-                                                "You might still be able to "
-                                                "use the service normally.");
-                emit currentJobChanged(giveUpString);
-                emit logMessage(giveUpString);
+                this->showStatusMessageAndLogIt(tr("Some initial data was not "
+                                                   "received after several "
+                                                   "attempts. Something might "
+                                                   "be wrong with your server. "
+                                                   "You might still be able to "
+                                                   "use the service normally."));
             }
         }
         else
         {
-            const QString completeString = tr("All initial data received. "
-                                              "Initialization complete.");
-            emit currentJobChanged(completeString);
-            emit logMessage(completeString);
-
-            // If there are no problems, this will just wait one interal,
+            this->showStatusMessageAndLogIt(tr("All initial data received. "
+                                               "Initialization complete."));
+            // If there are no problems, this will just wait one interval,
             // so it takes longer for the final (default) step to arrive
         }
         break;
@@ -2553,9 +2576,8 @@ void PumpController::getInitialData()
     default:
         initialDataTimer->stop();
 
-        const QString readyString = tr("Ready.");
-        emit currentJobChanged(readyString);
-        emit logMessage(readyString);
+        this->showStatusMessageAndLogIt(tr("Ready."));
+        emit initializationComplete();
 
         qDebug() << "--------------------------------------";
         qDebug() << "-- All initial data loaded -----------";
