@@ -141,6 +141,8 @@ public:
 
     void showTransientMessage(QString message);
 
+    void showStatusMessageAndLogIt(QString message);
+
     enum requestTypes
     {
         NoRequest,
@@ -207,6 +209,7 @@ signals:
     void openingAuthorizeURL(QUrl url);
     void authorizationFailed(QString errorTitle, QString errorMessage);
     void authorizationStatusChanged(bool authorized);
+    void initializationComplete();
 
     void profileReceived(QString avatarURL, QString fullName,
                          QString hometown, QString bio,
@@ -272,6 +275,7 @@ public slots:
 
     void getInitialData();
 
+
     void postNote(QMap<QString,QString> audienceMap,
                   QString postText,
                   QString postTitle);
