@@ -31,10 +31,8 @@ TimeLine::TimeLine(int timelineType,
     this->globalObj = globalObject;
     this->fChecker = filterChecker;
 
-    // Set 6 empty colors initially
-    this->highlightColorsList << "" << "" << "" << "" << "" << "";
-    // They will be set later, but the string list needs to have all 6 elements
-    // before the demo posts are created
+    this->setMinimumSize(180, 180); // Ensure something's always visible
+
 
 
     // Simulated data for demo posts
@@ -52,6 +50,7 @@ TimeLine::TimeLine(int timelineType,
 
     QVariantMap demoObjectData;
     demoObjectData.insert("objectType",     "note");
+    demoObjectData.insert("id",             "demo-post-id");
     demoObjectData.insert("published",      "2013-05-01T00:00:00Z");
 
 
@@ -145,11 +144,15 @@ TimeLine::TimeLine(int timelineType,
     demoPostData.insert("actor",          demoAuthorData);
     demoPostData.insert("generator",      demoGeneratorData);
     demoPostData.insert("object",         demoObjectData);
+    demoPostData.insert("id",             "demo-activity-id");
 
 
     this->unreadPostsCount = 0;
     this->timelineOffset = 0;
 
+    this->postsPerPage = 1;    // 1 at first, so initial page number calculation makes sense
+    this->totalItemsCount = 1; // For total page count, too.
+
     this->minMaxHeightForPosts = 400;
 
     firstPageButton = new QPushButton(QIcon::fromTheme("go-first"),
@@ -157,11 +160,20 @@ TimeLine::TimeLine(int timelineType,
     connect(firstPageButton, SIGNAL(clicked()),
             this, SLOT(goToFirstPage()));
 
-    // FIXME: turn this into a button, that will allow to jump to any page
-    currentPageLabel = new QLabel();
-    currentPageLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
-    currentPageLabel->setSizePolicy(QSizePolicy::Minimum,
-                                    QSizePolicy::Maximum);
+
+    this->pageSelector = new PageSelector(this);
+    connect(pageSelector, SIGNAL(pageJumpRequested(int)),
+            this, SLOT(goToSpecificPage(int)));
+
+
+    currentPageButton = new QPushButton();
+    currentPageButton->setFlat(true);
+    currentPageButton->setSizePolicy(QSizePolicy::MinimumExpanding,
+                                     QSizePolicy::Preferred);
+    connect(currentPageButton, SIGNAL(clicked()),
+            this, SLOT(showPageSelector()));
+
+
 
     previousPageButton = new QPushButton(QIcon::fromTheme("go-previous"),
                                          tr("Newer"));
@@ -182,7 +194,7 @@ TimeLine::TimeLine(int timelineType,
     bottomLayout->addSpacing(2);
     bottomLayout->addWidget(firstPageButton,    2);
     bottomLayout->addSpacing(4);
-    bottomLayout->addWidget(currentPageLabel,   0);
+    bottomLayout->addWidget(currentPageButton,  0);
     bottomLayout->addSpacing(4);
     bottomLayout->addWidget(previousPageButton, 2);
     bottomLayout->addWidget(nextPageButton,     2);
@@ -244,20 +256,19 @@ TimeLine::TimeLine(int timelineType,
     previousPageAction = new QAction(this);
     previousPageAction->setShortcut(QKeySequence("Ctrl+Left"));
     connect(previousPageAction, SIGNAL(triggered()),
-            this, SLOT(goToPreviousPage()));
+            previousPageButton, SLOT(click()));
     this->addAction(previousPageAction);
 
     nextPageAction = new QAction(this);
     nextPageAction->setShortcut(QKeySequence("Ctrl+Right"));
     connect(nextPageAction, SIGNAL(triggered()),
-            this, SLOT(goToNextPage()));
+            nextPageButton, SLOT(click()));
     this->addAction(nextPageAction);
 
 
     // Add the default "demo" post
     ASActivity *demoActivity = new ASActivity(demoPostData, this);
     Post *demoPost = new Post(demoActivity,
-                              highlightColorsList,
                               false, // Not highlighted
                               false, // Not standalone
                               pController,
@@ -268,6 +279,9 @@ TimeLine::TimeLine(int timelineType,
     postsInTimeline.append(demoPost);
     postsLayout->addWidget(demoPost);
 
+
+    this->updateCurrentPageNumber();
+
     qDebug() << "TimeLine created";
 }
 
@@ -348,30 +362,69 @@ void TimeLine::requestTimelinePage()
 }
 
 
+int TimeLine::getCurrentPage()
+{
+    if (this->postsPerPage == 0)
+    {
+        this->postsPerPage = 1;
+    }
+
+    return (this->timelineOffset / this->postsPerPage) + 1;
+}
+
+int TimeLine::getTotalPages()
+{
+    if (this->postsPerPage == 0)
+    {
+        this->postsPerPage = 1;
+    }
+
+    return qCeil(this->totalItemsCount / (float)this->postsPerPage);
+}
+
+
 /*
- *  Update the label at the bottom of the page, indicating current "page"
+ *  Update the button at the bottom of the page, indicating current "page"
  *
- *  FIXME: turn the label into a button, that will show a dialog to jump to any page
  */
 void TimeLine::updateCurrentPageNumber()
 {
-    int currentPage = (this->timelineOffset / this->postsPerPage) + 1;
-    int totalPages = qCeil(this->totalItemsCount / (float)this->postsPerPage);
+    int currentPage = this->getCurrentPage();
+    int totalPages = this->getTotalPages();
 
-    this->currentPageLabel->setText(QString("%1 / %2")
-                                    .arg(currentPage)
-                                    .arg(totalPages));
-    this->currentPageLabel->setToolTip(tr("Page %1 of %2.")
-                                       .arg(currentPage)
-                                       .arg(totalPages)
-                                       + "\n"
-                                       + tr("Showing %1 posts per page.")
-                                         .arg(this->postsPerPage)
-                                       + "\n"
-                                       + tr("%1 posts in total.")
-                                         .arg(this->totalItemsCount));
+    this->currentPageButton->setText(QString("%1 / %2")
+                                     .arg(currentPage)
+                                     .arg(totalPages));
+    // The shortcut needs to be set each time the text is changed
+    currentPageButton->setShortcut(QKeySequence("Ctrl+G"));
+
+    this->currentPageButton->setToolTip(tr("Page %1 of %2.")
+                                        .arg(currentPage)
+                                        .arg(totalPages)
+                                        + "<br>"
+                                        + tr("Showing %1 posts per page.")
+                                          .arg(this->postsPerPage)
+                                        + "<br>"
+                                        + tr("%1 posts in total.")
+                                          .arg(this->totalItemsCount)
+                                        + "<hr>"
+                                          "<b><i>"
+                                        + tr("Click here or press Control+G to "
+                                             "jump to a specific page")
+                                        + "</i></b>");
+
+    if (currentPage == totalPages)
+    {
+        this->nextPageButton->setDisabled(true);
+    }
+    else
+    {
+        this->nextPageButton->setEnabled(true);
+    }
 }
 
+
+
 void TimeLine::setMinMaxHeightForPosts(int newMinMaxHeightForPosts)
 {
     this->minMaxHeightForPosts = newMinMaxHeightForPosts;
@@ -414,11 +467,6 @@ void TimeLine::updateFuzzyTimestamps()
     }
 }
 
-void TimeLine::updateHighlightColors(QStringList colorList)
-{
-    highlightColorsList = colorList;
-}
-
 
 
 /*********************************************************/
@@ -542,7 +590,6 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
                 }
 
                 Post *newPost = new Post(activity,
-                                         highlightColorsList,
                                          highlightedByFilter,
                                          false,  // NOT standalone
                                          pController,
@@ -720,6 +767,22 @@ void TimeLine::goToNextPage()
 }
 
 
+void TimeLine::goToSpecificPage(int pageNumber)
+{
+    qDebug() << "TimeLine::goToSpecificPage(): " << pageNumber;
+
+    this->timelineOffset = (pageNumber - 1) * this->postsPerPage;
+    this->requestTimelinePage();
+}
+
+
+void TimeLine::showPageSelector()
+{
+    this->pageSelector->showForPage(this->getCurrentPage(),
+                                    this->getTotalPages());
+}
+
+
 
 void TimeLine::scrollUp()
 {
