@@ -37,6 +37,7 @@
 #include "asactivity.h"
 #include "post.h"
 #include "filterchecker.h"
+#include "pageselector.h"
 
 
 class TimeLine : public QWidget
@@ -53,6 +54,8 @@ public:
 
     void clearTimeLineContents();
     void requestTimelinePage();
+    int getCurrentPage();
+    int getTotalPages();
     void updateCurrentPageNumber();
 
     void setMinMaxHeightForPosts(int newMinMaxHeightForPosts);
@@ -62,8 +65,6 @@ public:
 
     void updateFuzzyTimestamps();
 
-    void updateHighlightColors(QStringList colorList);
-
 
 
     enum TimelineTypes
@@ -105,6 +106,9 @@ public slots:
     void goToFirstPage();
     void goToPreviousPage();
     void goToNextPage();
+    void goToSpecificPage(int pageNumber);
+
+    void showPageSelector();
 
     void scrollUp();
     void scrollDown();
@@ -128,7 +132,7 @@ private:
     FilterChecker *fChecker;
 
     QPushButton *firstPageButton;
-    QLabel *currentPageLabel;
+    QPushButton *currentPageButton;
     QPushButton *previousPageButton;
     QPushButton *nextPageButton;
 
@@ -145,6 +149,8 @@ private:
     QAction *previousPageAction;
     QAction *nextPageAction;
 
+    PageSelector *pageSelector;
+
     int timelineType;
 
     int timelineOffset;
@@ -155,7 +161,6 @@ private:
 
     int minMaxHeightForPosts;
 
-    QStringList highlightColorsList;
 
     QString previousNewestPostId;
 
